#customize-theme-controls ul.customize-pane-parent>[id$=wb4wp_header_section],#customize-theme-controls ul.customize-pane-parent>[id$=wb4wp_style_section],#customize-theme-controls ul.customize-pane-parent>[id$=wb4wp_blog_pages_panel],#customize-theme-controls ul.customize-pane-parent>[id$=wb4wp_contact_information_section],#customize-theme-controls ul.customize-pane-parent>#accordion-section-title_tagline{margin-top:12px;border-top:1px solid #ddd !important}#customize-theme-controls ul[id$=wb4wp_style_section]>li[id$=accent1_setting_control]:before{content:"Colors";display:block;margin:0 -12px 12px;padding:12px;background-color:#fff;border-top:1px solid #ddd;border-bottom:1px solid #ddd;letter-spacing:.1em;text-transform:uppercase;font-size:11px}#customize-theme-controls ul[id$=wb4wp_style_section]>li[id$=heading_setting_control]:before{content:"Fonts";display:block;margin:0 -12px 12px;padding:12px;background-color:#fff;border-top:1px solid #ddd;border-bottom:1px solid #ddd;letter-spacing:.1em;text-transform:uppercase;font-size:11px}
