.wp-block-jetpack-map .wp-block-jetpack-map__gm-container{width:100%;overflow:hidden;background:#ddd;min-height:400px;text-align:left}.wp-block-jetpack-map .mapboxgl-popup{max-width:300px}.wp-block-jetpack-map .mapboxgl-popup h3{font-size:1.3125em;font-weight:400;margin-bottom:.5rem}.wp-block-jetpack-map .mapboxgl-popup p{margin-bottom:0}.wp-block-jetpack-map .mapboxgl-ctrl-group button{border-radius:0;background-color:transparent!important}.wp-block-jetpack-map-marker{width:32px;height:38px;opacity:.9}