.grid-col-2{display:-ms-grid;display:grid;-ms-grid-columns:minmax(0, 1fr);grid-template-columns:minmax(0, 1fr);margin-top:2rem;grid-gap:2rem}@media screen and (min-width: 768px){.grid-col-2{-ms-grid-columns:(minmax(0, 1fr))[2];grid-template-columns:repeat(2, minmax(0, 1fr))}}.nf-onboarding__loading{text-align:center;margin:5vw auto}@media screen and (min-width: 782px){.nf-onboarding__loading{max-width:25vw}}.nf-onboarding__header-desc{font-size:16px}.nf-onboarding__desktop{display:flex;flex-direction:row}.nf-onboarding__desktop .components-tab-panel__tabs{width:240px;min-width:240px;flex-direction:column}.nf-onboarding__desktop .components-tab-panel__tabs-item{color:var(--bh-gray);text-align:left;border-left:4px solid transparent;font-size:1rem}.nf-onboarding__desktop .components-tab-panel__tabs-item.is-active{border-left-color:var(--nf-primary);color:var(--nf-primary);box-shadow:none;font-weight:500}.nf-onboarding__desktop .components-tab-panel__tabs-item:focus:not(:disabled),.nf-onboarding__desktop .components-tab-panel__tabs-item:hover:not(:disabled){box-shadow:none;color:var(--nf-primary)}.nf-onboarding__desktop .components-tab-panel__tab-content{padding-left:1rem;margin:0 auto}.nf-onboarding-base-step{max-width:735px}.nf-onboarding-base-step img{display:block;height:auto;margin:0 auto;max-width:425px;max-height:320px}.nf-onboarding-base-step p{font-size:1.25rem;line-height:1.5}div.nf-onboarding__mobile{background-color:transparent;padding:0}div.nf-onboarding__mobile .components-navigation__item-title,div.nf-onboarding__mobile .components-navigation__menu-title-heading,div.nf-onboarding__mobile .components-navigation__back-button,div.nf-onboarding__mobile .nf-onboarding-base-step p{color:#545454}div.nf-onboarding__mobile .components-navigation__item-title:active:not(:disabled),div.nf-onboarding__mobile .components-navigation__item-title:focus:not(:disabled),div.nf-onboarding__mobile .components-navigation__item-title:hover:not(:disabled),div.nf-onboarding__mobile .components-navigation__back-button:active:not(:disabled),div.nf-onboarding__mobile .components-navigation__back-button:focus:not(:disabled),div.nf-onboarding__mobile .components-navigation__back-button:hover:not(:disabled){color:var(--nf-primary)}
.component-template-common{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-common{padding:46px 0 24px}}@media(max-width: 600px){.component-template-common{padding-left:16px;padding-right:16px}}.page-fade-speed{-webkit-animation-duration:315ms;animation-duration:315ms}
.component-template-marketplace{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-marketplace{padding:46px 0 24px}}@media(max-width: 600px){.component-template-marketplace{padding-left:16px;padding-right:16px}}.bluehost-marketplace__header-primary{display:flex;justify-content:space-between;align-items:center;flex-wrap:wrap}.bluehost-marketplace__header-primary .marketplace-page-title{margin-top:0 !important;margin-bottom:0 !important;position:relative;top:-28px}@media screen and (min-width: 768px){.bluehost-marketplace__header-primary{max-height:64px}}.bluehost-marketplace__header-primary .pagination{margin-top:0}.bluehost-marketplace__header-secondary{display:flex;justify-content:space-between;align-items:center;margin-bottom:9px;flex-wrap:wrap}.bluehost-marketplace__header-secondary .search-box{margin-right:2em}.bluehost-marketplace__header-secondary .dropdown__label{font-weight:600}.bluehost-marketplace__pagination-container{min-height:96px}.bluehost-marketplace__footer{display:flex;justify-content:space-between;align-items:flex-start;margin-top:9px}.bluehost-marketplace__footer .pagination{margin-top:0}@media(max-width: 624px){.bluehost-marketplace h1{margin-top:0}.bluehost-marketplace .pagination{margin-top:1rem}.bluehost-marketplace .search-box{margin-bottom:1rem}}@media(max-width: 687px){.bluehost-marketplace .search-box{margin-bottom:1rem}}
