div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block{position:relative}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block:before{content:"";position:absolute;top:0;right:0;bottom:0;left:0;z-index:10;-webkit-backdrop-filter:brightness(85%) contrast(120%);backdrop-filter:brightness(85%) contrast(120%);transition:ease-in 0.16s opacity;opacity:0}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block:hover:before,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block.is-selected:before{content:"";opacity:1}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block:hover .express-block-button,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block.is-selected .express-block-button{transform:scale(1);opacity:1}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .wp-block,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper{margin-left:0;margin-right:0}@media (min-width: 1024px){div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .wp-block,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper{max-width:calc(100vw - 480px)}}@media (min-width: 1600px){div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .wp-block,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper{max-width:1000px}}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block{margin-left:auto;margin-right:auto}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper{position:relative}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper .kv-main,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper section,div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper .kv-full-page{height:auto;min-height:auto}div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper .kv-full-page{padding-top:64px;padding-bottom:64px}@media (min-width: 1024px){div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper .kv-full-page{padding-top:32px;padding-bottom:32px}}@media (min-width: 1152px){div[data-type="wb4wp/block-generic-section"].block-editor-block-list__block .express-block-wrapper .kv-full-page{padding-top:64px;padding-bottom:64px}}.express-block-wrapper{border-radius:8px;padding-bottom:0px;padding-top:0px;position:relative}.express-block-wrapper .express-block{cursor:pointer}.express-block-wrapper:hover .express-block-overlay{visibility:visible;opacity:1}.express-block-button-wrapper{position:-webkit-sticky;position:sticky;top:0;z-index:24;display:flex;justify-content:flex-end}.express-block-button-wrapper .express-block-button{top:16px;right:16px;position:absolute;opacity:0;transform:scale(0.75) translateY(-10px);transition:0.2s transform cubic-bezier(0.4, 0.78, 0.18, 1.4),0.2s opacity ease-in}#editor .kv-ee-section{height:auto}@media (min-width: 1200px){body .wp-block[data-align="full"]{max-width:1200px}body .wp-block[data-align="full"] .kv-ee-container{max-width:75%}}

