#go-to-wb4wp-editor{border:1px solid rgba(0,0,0,0.1);box-shadow:0px 4px 8px rgba(0,0,0,0.1);border-radius:4px;margin-left:auto;margin-right:auto;margin-bottom:80px;max-width:870px;padding:40px 100px;background-color:#fff;transition:box-shadow 0.24s cubic-bezier(0.7, 0.35, 0.35, 0.9)}#go-to-wb4wp-editor:hover{cursor:pointer;box-shadow:0px 8px 12px rgba(0,0,0,0.16)}#go-to-wb4wp-editor .title,#go-to-wb4wp-editor .copy{font-family:'Nunito Sans', sans-serif;color:#424242;text-align:center;font-style:normal;margin:0}#go-to-wb4wp-editor .title{font-weight:bold;font-size:28px;line-height:36px;margin-bottom:20px}#go-to-wb4wp-editor .copy{font-weight:normal;font-size:16px;line-height:24px}#go-to-wb4wp-editor .logo{text-align:center;margin:0 auto;width:100%;max-width:420px}#go-to-wb4wp-editor .logo img{height:160px}#go-to-wb4wp-editor .button-bar{margin-top:32px;text-align:center}

