!function(e){var t={};function n(r){if(t[r])return t[r].exports;var c=t[r]={i:r,l:!1,exports:{}};return e[r].call(c.exports,c,c.exports,n),c.l=!0,c.exports}n.m=e,n.c=t,n.d=function(e,t,r){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var c in e)n.d(r,c,function(t){return e[t]}.bind(null,c));return r},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=24)}({0:function(e,t){!function(){e.exports=this.wp.element}()},14:function(e,t){e.exports=React},24:function(e,t,n){"use strict";n.r(t);var r=n(8),c=n(0),l=(n(14),n(5)),o=function(e){var t=window.wp.blockEditor.useBlockProps.save({className:e.attributes.backgroundId||""});return Object(c.createElement)("div",t,Object(c.createElement)("div",{className:"wp-block-wb4wp-container__background"},Object(c.createElement)(c.RawHTML,null,e.attributes.backgroundHTML)),Object(c.createElement)("div",{className:"wp-block-wb4wp-container__inner-container kv-content wp-embed-responsive"},Object(c.createElement)("div",{className:"kv-ee-container"},Object(c.createElement)(l.InnerBlocks.Content,null))))},a=function(e){var t=window.wp.blockEditor.useBlockProps({className:e.attributes.backgroundId||""});return Object(c.createElement)("div",t,Object(c.createElement)("div",{className:"wp-block-wb4wp-container__background"},Object(c.createElement)(c.RawHTML,null,e.attributes.backgroundHTML)),Object(c.createElement)("div",{className:"wp-block-wb4wp-container__inner-container kv-content wp-embed-responsive"},Object(c.createElement)("div",{className:"kv-ee-container"},Object(c.createElement)(l.InnerBlocks,null))))};Object(r.registerBlockType)("wb4wp/container",{title:"Website Builder Container",description:"Gutenberg section that's built in the Bluehost Website Builder.",icon:function(){return Object(c.createElement)("svg",{xmlns:"http://www.w3.org/2000/svg",version:"1.0",width:"159.000000pt",height:"160.000000pt",viewBox:"0 0 159.000000 160.000000",preserveAspectRatio:"xMidYMid meet"},Object(c.createElement)("g",{transform:"translate(0.000000,160.000000) scale(0.100000,-0.100000)",stroke:"none"},Object(c.createElement)("path",{fill:"#3575d3",d:"M310 1150 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M660 1150 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M1000 1150 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M310 800 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M660 800 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M1000 800 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M310 450 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M660 450 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(c.createElement)("path",{fill:"#3575d3",d:"M1000 450 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"})))},category:"layout",supports:{inserter:!1,customClassName:!1},attributes:{id:{type:["string","number"]},backgroundHTML:{type:"string",source:"html",selector:"div.wp-block-wb4wp-container__background"},backgroundId:{type:"string"},background:{type:"string",default:"{}"}},edit:a,save:o})},5:function(e,t){!function(){e.exports=this.wp.blockEditor}()},8:function(e,t){!function(){e.exports=this.wp.blocks}()}});