.page-home__container{max-width:822px}.page-home__container .welcome-section{max-width:600px;margin-bottom:48px}.page-home__container .welcome-section p{font-size:16px}
.component-template-common{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-common{padding:46px 0 24px}}@media(max-width: 600px){.component-template-common{padding-left:16px;padding-right:16px}}.page-fade-speed{-webkit-animation-duration:315ms;animation-duration:315ms}
.component-template-marketplace{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-marketplace{padding:46px 0 24px}}@media(max-width: 600px){.component-template-marketplace{padding-left:16px;padding-right:16px}}.bluehost-marketplace__header-primary{display:flex;justify-content:space-between;align-items:center;flex-wrap:wrap}.bluehost-marketplace__header-primary .marketplace-page-title{margin-top:0 !important;margin-bottom:0 !important;position:relative;top:-28px}@media screen and (min-width: 768px){.bluehost-marketplace__header-primary{max-height:64px}}.bluehost-marketplace__header-primary .pagination{margin-top:0}.bluehost-marketplace__header-secondary{display:flex;justify-content:space-between;align-items:center;margin-bottom:9px;flex-wrap:wrap}.bluehost-marketplace__header-secondary .search-box{margin-right:2em}.bluehost-marketplace__header-secondary .dropdown__label{font-weight:600}.bluehost-marketplace__pagination-container{min-height:96px}.bluehost-marketplace__footer{display:flex;justify-content:space-between;align-items:flex-start;margin-top:9px}.bluehost-marketplace__footer .pagination{margin-top:0}@media(max-width: 624px){.bluehost-marketplace h1{margin-top:0}.bluehost-marketplace .pagination{margin-top:1rem}.bluehost-marketplace .search-box{margin-bottom:1rem}}@media(max-width: 687px){.bluehost-marketplace .search-box{margin-bottom:1rem}}
