.page-product img{max-width:100%}.page-product img[src*="spacer-sygRO.png"]{display:block}.page-product__breadcrumbs{font-size:14px;line-height:24px;margin:10px 0 20px 0}.page-product__breadcrumbs-root{background:transparent;border:none;color:#6f6f6f;margin:0;padding:0}.page-product__breadcrumbs-root:hover{color:#3575d3}.page-product__main{background:#fff;display:flex}.page-product__content{flex-grow:1;flex-shrink:1;padding:25px 50px 25px 25px}.page-product__sidebar{flex-basis:380px;flex-shrink:0}.page-product__title{margin-bottom:35px !important}.page-product__pricing-panel{border-bottom:2px solid #eee;border-left:2px solid #eee;padding:50px;text-align:center}.page-product__pricing-panel-price{font-size:3rem;line-height:1}.page-product__pricing-panel-currency{font-size:1rem;line-height:1.4;margin-bottom:1.5rem}.page-product__pricing-panel-terms{font-size:1rem;line-height:1.4;margin-top:1.5rem}.page-product__info-panel{margin-top:10px;padding:50px;border-bottom:2px solid #eee;border-left:2px solid #eee}.page-product__info-panel-title{font-size:1.5rem;line-height:1;margin-top:0}.page-product__info-panel-created,.page-product__info-panel-updated,.page-product__info-panel-sales{font-size:1rem;line-height:2rem}
.component-template-common{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-common{padding:46px 0 24px}}@media(max-width: 600px){.component-template-common{padding-left:16px;padding-right:16px}}.page-fade-speed{-webkit-animation-duration:315ms;animation-duration:315ms}
.component-template-marketplace{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-marketplace{padding:46px 0 24px}}@media(max-width: 600px){.component-template-marketplace{padding-left:16px;padding-right:16px}}.bluehost-marketplace__header-primary{display:flex;justify-content:space-between;align-items:center;flex-wrap:wrap}.bluehost-marketplace__header-primary .marketplace-page-title{margin-top:0 !important;margin-bottom:0 !important;position:relative;top:-28px}@media screen and (min-width: 768px){.bluehost-marketplace__header-primary{max-height:64px}}.bluehost-marketplace__header-primary .pagination{margin-top:0}.bluehost-marketplace__header-secondary{display:flex;justify-content:space-between;align-items:center;margin-bottom:9px;flex-wrap:wrap}.bluehost-marketplace__header-secondary .search-box{margin-right:2em}.bluehost-marketplace__header-secondary .dropdown__label{font-weight:600}.bluehost-marketplace__pagination-container{min-height:96px}.bluehost-marketplace__footer{display:flex;justify-content:space-between;align-items:flex-start;margin-top:9px}.bluehost-marketplace__footer .pagination{margin-top:0}@media(max-width: 624px){.bluehost-marketplace h1{margin-top:0}.bluehost-marketplace .pagination{margin-top:1rem}.bluehost-marketplace .search-box{margin-bottom:1rem}}@media(max-width: 687px){.bluehost-marketplace .search-box{margin-bottom:1rem}}
