html, body {
    word-wrap: break-word;
    -webkit-line-break: after-white-space;
}

html.kv-zooming, body.kv-zooming {
    height: 100%;
    overflow: hidden;
    width: 100%;
    position: fixed;
}

.kv-control-placeholder {
    display: none;
}

.position-relative {
    position: relative;
}

.kv-background {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    overflow: hidden;
}

.kv-background .kv-background-inner, .kv-background .kv-parallax-container {
    /*z-index: -10;*/
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;

    background-repeat: no-repeat;
    background-attachment: scroll;
    background-position: center center;
    background-size: cover;
}

.kv-parallax-container {
    transform: scale(1.4);
    transform-origin: center;
}

.kv-background .pattern-white-0, .kv-background .pattern-white-1, .kv-background .pattern-white-2, .kv-background .pattern-white-3, .kv-background .pattern-white-4, .kv-background .pattern-white-5, .kv-background .pattern-white-6, .kv-background .pattern-white-7,
.kv-background .pattern-black-0, .kv-background .pattern-black-1, .kv-background .pattern-black-2, .kv-background .pattern-black-3, .kv-background .pattern-black-4, .kv-background .pattern-black-5, .kv-background .pattern-black-6, .kv-background .pattern-black-7 {
    background-size: unset;
    background-repeat: repeat;
    opacity: 0.2;
}

.kv-background .pattern-black-0 {
    background-image: url(./assets/images/patterns/black/honeycomb.svg) !important;
    background-size: 44px 68px;
}
.kv-background .pattern-black-1 {
    background-image: url(./assets/images/patterns/black/plaid.svg) !important;
    background-size: 96px 96px;
}
.kv-background .pattern-black-2 {
    background-image: url(./assets/images/patterns/black/dust.svg) !important;
    background-size: 300px 300px;
}
.kv-background .pattern-black-3 {
    background-image: url(./assets/images/patterns/black/confetti.svg) !important;
    background-size: 215px 215px;
}
.kv-background .pattern-black-4 {
    background-image: url(./assets/images/patterns/black/metal.svg) !important;
    background-size: 47px 47px;
}
.kv-background .pattern-black-5 {
    background-image: url(./assets/images/patterns/black/dotgrid.svg) !important;
    background-size: 16px 16px;
}
.kv-background .pattern-black-6 {
    background-image: url(./assets/images/patterns/black/qbert.svg) !important;
    background-size: 72px 116px;
}
.kv-background .pattern-black-7 {
    background-image: url(./assets/images/patterns/black/landscape.svg) !important;
    background-size: 200px 200px;
}

.kv-background .pattern-white-0 {
    background-image: url(./assets/images/patterns/white/honeycomb.svg) !important;
    background-size: 44px 68px;
}
.kv-background .pattern-white-1 {
    background-image: url(./assets/images/patterns/white/plaid.svg) !important;
    background-size: 96px 96px;
}
.kv-background .pattern-white-2 {
    background-image: url(./assets/images/patterns/white/dust.svg) !important;
    background-size: 300px 300px;
}
.kv-background .pattern-white-3 {
    background-image: url(./assets/images/patterns/white/confetti.svg) !important;
    background-size: 215px 215px;
}
.kv-background .pattern-white-4 {
    background-image: url(./assets/images/patterns/white/metal.svg) !important;
    background-size: 47px 47px;
}
.kv-background .pattern-white-5 {
    background-image: url(./assets/images/patterns/white/dotgrid.svg) !important;
    background-size: 16px 16px;
}
.kv-background .pattern-white-6 {
    background-image: url(./assets/images/patterns/white/qbert.svg) !important;
    background-size: 72px 116px;
}
.kv-background .pattern-white-7 {
    background-image: url(./assets/images/patterns/white/landscape.svg) !important;
    background-size: 200px 200px;
}

.kv-full-page {
    min-height: 300px;
    min-height: 100vh;
}

/* Smooth transition for background animation */
@keyframes animateImage {
    0%,100% {
        -webkit-transform: matrix3d(1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1)
    }

    35% {
        -webkit-transform: matrix3d(1.15,0,0,0,0,1.15,0,0,0,0,1,0,-40,-40,0,1)
    }
}