<?php

namespace Wb4Wp\Constants;

/**
 * Class EnvironmentNames
 *
 * @package Wb4Wp\Constants
 */
final class Environment_Names {

	const DEVELOPMENT = 'dev';
	const QA          = 'qa';
	const UAT         = 'uat';
	const PRODUCTION  = 'prod';
}
