div.juxtapose{width:100%;font-family:Helvetica,Arial,sans-serif}div.jx-slider{width:100%;height:100%;position:relative;overflow:hidden;cursor:pointer;color:#f3f3f3}div.jx-handle{position:absolute;height:100%;width:40px;cursor:col-resize;z-index:15;margin-right:-20px}.vertical div.jx-handle{height:40px;width:100%;cursor:row-resize;margin-top:-20px;margin-right:0}div.jx-control{height:100%;margin-left:auto;margin-right:auto;width:3px;background-color:currentColor}.vertical div.jx-control{height:3px;width:100%;background-color:currentColor;position:relative;top:50%;transform:translateY(-50%)}div.jx-controller{position:absolute;top:0;bottom:0;height:60px;width:9px;margin:auto -3px auto auto;background-color:currentColor}.vertical div.jx-controller{height:9px;width:100px;margin-right:auto;margin-left:auto;top:-3px;position:relative}div.jx-arrow{margin:auto;top:0;bottom:0}.vertical div.jx-arrow,div.jx-arrow{position:absolute;width:0;height:0;transition:all .2s ease}.vertical div.jx-arrow{margin:0 auto;right:0;left:0}div.jx-arrow.jx-left{right:2px;border-color:transparent transparent transparent currentcolor;border-style:solid;border-width:8px 0 8px 8px}div.jx-arrow.jx-right{left:2px;border-color:transparent currentcolor transparent transparent;border-style:solid;border-width:8px 8px 8px 0}.vertical div.jx-arrow.jx-left{right:0;top:2px;border-color:transparent transparent currentcolor;border-style:solid;border-width:0 8px 8px}.vertical div.jx-arrow.jx-right{left:0;top:auto;bottom:2px;border-color:currentcolor transparent transparent;border-style:solid;border-width:8px 8px 0}div.jx-handle:active div.jx-arrow.jx-left,div.jx-handle:hover div.jx-arrow.jx-left{right:-1px}div.jx-handle:active div.jx-arrow.jx-right,div.jx-handle:hover div.jx-arrow.jx-right{left:-1px}.vertical div.jx-handle:active div.jx-arrow.jx-left,.vertical div.jx-handle:hover div.jx-arrow.jx-left{right:0;top:0}.vertical div.jx-handle:active div.jx-arrow.jx-right,.vertical div.jx-handle:hover div.jx-arrow.jx-right{left:0;bottom:0}div.jx-image{position:absolute;height:100%;display:inline-block;top:0;overflow:hidden}.vertical div.jx-image{width:100%;right:0;top:auto}div.jx-slider div.jx-image img{height:100%!important;width:auto!important;z-index:5;position:absolute;margin-bottom:0;max-width:none!important;max-height:none!important}div.jx-slider.vertical div.jx-image img{height:auto!important;width:100%!important}div.jx-image.jx-left{right:0;background-position:100%}div.jx-image.jx-left img{right:0}div.jx-image.jx-right{left:0;background-position:0}div.jx-image.jx-right img{left:0;bottom:0}.veritcal div.jx-image.jx-left{top:0;background-position:top}.veritcal div.jx-image.jx-left img{top:0}.vertical div.jx-image.jx-right{bottom:0;background-position:bottom}.veritcal div.jx-image.jx-right img{bottom:0}div.jx-image div.jx-label{font-size:1em;padding:.25em .75em;position:relative;display:inline-block;top:0;background-color:#000;background-color:rgba(0,0,0,.7);color:#fff;z-index:10;white-space:nowrap;line-height:18px;vertical-align:middle}div.jx-image.jx-left div.jx-label{float:right;right:0}div.jx-image.jx-right div.jx-label{float:left;left:0}.vertical div.jx-image div.jx-label{display:table;position:absolute}.vertical div.jx-image.jx-right div.jx-label{right:0;bottom:0;top:auto}div.jx-image.transition{transition:width .5s ease}div.jx-handle.transition{transition:right .5s ease}.vertical div.jx-image.transition{transition:height .5s ease}.vertical div.jx-handle.transition{transition:top .5s ease}div.jx-controller:focus,div.jx-image.jx-left div.jx-label:focus,div.jx-image.jx-right div.jx-label:focus,figure.wp-block-jetpack-image-compare figcaption{text-align:center;font-size:85%}div.jx-control{color:#fff}.vertical div.jx-controller,div.jx-controller{width:48px;height:48px;border-radius:50%}div.jx-controller{margin-right:-22.5px}.vertical div.jx-controller{transform:translateY(-19.5px)}.vertical div.jx-arrow.jx-left,.vertical div.jx-arrow.jx-right,div.jx-arrow.jx-left,div.jx-arrow.jx-right{width:24px;height:24px;border:none;background-repeat:no-repeat;z-index:1;will-change:transform}div.jx-arrow.jx-left{background-image:url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCI+PHBhdGggZD0iTTEzLjQgMThMOCAxMmw1LjQtNiAxLjIgMS00LjYgNSA0LjYgNXoiLz48L3N2Zz4=");right:0}div.jx-arrow.jx-right{background-image:url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCI+PHBhdGggZD0iTTEwLjYgNkw5LjQgN2w0LjYgNS00LjYgNSAxLjIgMSA1LjQtNnoiLz48L3N2Zz4=");left:0}div.vertical div.jx-arrow.jx-left,div.vertical div.jx-arrow.jx-right{transform:rotate(-90deg)}