/*--------------------------------------------------------------
 * CMB2 Frontend
--------------------------------------------------------------*/

.closed .inside {
	display: none;
}

.cmb-repeatable-grouping {
	position: relative;

	.cmb-group-title {
		margin-left: -1em;
		margin-right: -1em;
		min-height: 1.5em;
	}

	h3 {
		font-size: 14px;
		padding: 8px 12px;
		margin: 0;
		line-height: 1.4;
	}

}

.cmb-repeatable-group {

	&.repeatable .cmb-group-title {
		padding-left: 2.2em;
	}

	&.non-repeatable .cmb-group-title {
		padding-left: 12px;
	}

}

.cmb-type-group .cmb-row .cmbhandle {
	right: 0;
	position: absolute;
}

.cmb-spinner {
	background: url(/wp-admin/images/spinner.gif) no-repeat;
	-webkit-background-size: 20px 20px;
	background-size: 20px 20px;
	display: none;
	float: right;
	vertical-align: middle;
	opacity: 0.7;
	filter: alpha(opacity=70);
	width: 20px;
	height: 20px;
	margin: 4px 10px 0;
}

.cmb2-char-max-msg {
	display: none;
}