.block-generic-wb4wp-content.express-block-wrapper{border-radius:8px;margin-left:20px;margin-right:20px;padding-bottom:0px;padding-top:0px}.block-generic-wb4wp-content.express-block-wrapper .express-block{border:1px solid rgba(0,0,0,0.15);box-shadow:rgba(0,0,0,0.1) 0px 0px 7px 3px;border-radius:8px;cursor:pointer}.block-generic-wb4wp-content.express-block-wrapper .express-block-button{visibility:hidden;display:flex;text-align:center;position:absolute;top:0;right:20px;left:20px;bottom:0;align-items:center;justify-content:center;background:rgba(0,0,0,0.56);opacity:0;transition:opacity 0.3s ease-in-out}.block-generic-wb4wp-content.express-block-wrapper:hover .express-block-button{visibility:visible;opacity:1}

