#wb4wp-switch-theme-confirmation_modal-root{font-family:"Nunito Sans", sans-serif;position:fixed;inset:0;background-color:rgba(0,0,0,0.4);z-index:99999;display:flex;justify-content:center;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}#wb4wp-switch-theme-confirmation_modal-root .modal{width:745px;background-color:#FFFFFF;border-radius:4px}#wb4wp-switch-theme-confirmation_modal-root .modal__header{padding:20px;background-color:#F6F6F6;border-top-left-radius:inherit;border-top-right-radius:inherit;display:flex;justify-content:space-between;box-shadow:inset 0 -1px 0 rgba(0,0,0,0.1)}#wb4wp-switch-theme-confirmation_modal-root .modal__header h3{margin:0}#wb4wp-switch-theme-confirmation_modal-root .modal__close{margin:-6.5px -8px;padding:6.5px 8px;border-radius:4px;cursor:pointer;transition:background-color 250ms ease-in-out}#wb4wp-switch-theme-confirmation_modal-root .modal__close:hover{background-color:rgba(0,0,0,0.1)}#wb4wp-switch-theme-confirmation_modal-root .modal__content{padding:24px;display:flex}#wb4wp-switch-theme-confirmation_modal-root .modal__content img{width:240px;height:100%;margin-right:24px}#wb4wp-switch-theme-confirmation_modal-root .modal__content p:first-child{margin-top:0}#wb4wp-switch-theme-confirmation_modal-root .modal__content p:last-child{margin-bottom:0}#wb4wp-switch-theme-confirmation_modal-root .modal__footer{display:flex;flex-direction:row-reverse;border-bottom-left-radius:inherit;border-bottom-right-radius:inherit;box-shadow:inset 0 1px 0 rgba(0,0,0,0.1)}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button{position:relative;margin:8px;padding:8px 16px;border-radius:4px;font-weight:bold;color:white;background-color:var(--button-color);border:none;transition:background-color 250ms ease-in-out;cursor:pointer}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button+button{margin-right:0}@-webkit-keyframes dot-dot-dot{0%{content:''}25%{content:'.'}50%{content:'. .'}75%{content:'. . .'}100%{content:''}}@keyframes dot-dot-dot{0%{content:''}25%{content:'.'}50%{content:'. .'}75%{content:'. . .'}100%{content:''}}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button.processing::after{content:'';display:block;position:absolute;bottom:0;left:0;right:0;-webkit-animation:dot-dot-dot 2s linear infinite;animation:dot-dot-dot 2s linear infinite;text-align:center}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button:focus,#wb4wp-switch-theme-confirmation_modal-root .modal__footer button:hover{background-color:var(--button-focus-color);outline:none}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button,#wb4wp-switch-theme-confirmation_modal-root .modal__footer button.primary{--button-color: #0076DF;--button-focus-color: #0050C7;--button-outline-background-color: rgba(0, 118, 223, 0.04)}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button.error{--button-color: #D42424;--button-focus-color: #920125;--button-outline-background-color: rgba(212, 36, 36, 0.04)}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button.outline{color:var(--button-color);background-color:transparent;border:1px solid var(--button-color);transition:color 250ms ease-in-out, background-color 250ms ease-in-out, border-color 250ms ease-in-out}#wb4wp-switch-theme-confirmation_modal-root .modal__footer button.outline:focus,#wb4wp-switch-theme-confirmation_modal-root .modal__footer button.outline:hover{color:var(--button-focus-color);background-color:var(--button-outline-background-color);border-color:var(--button-focus-color)}#wb4wp-switch-theme-confirmation_modal-root .modal a[href]{color:#0076DF}

