!function(e){var t={};function n(r){if(t[r])return t[r].exports;var i=t[r]={i:r,l:!1,exports:{}};return e[r].call(i.exports,i,i.exports,n),i.l=!0,i.exports}n.m=e,n.c=t,n.d=function(e,t,r){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var i in e)n.d(r,i,function(t){return e[t]}.bind(null,i));return r},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=27)}({0:function(e,t){!function(){e.exports=this.wp.element}()},27:function(e,t,n){"use strict";n.r(t);var r=n(0),i=n(8),o=n(7),l=n(5);Object(i.registerBlockType)("wb4wp/block-generic-wb4wp-content",{title:"Website Builder Section",icon:Object(r.createElement)("svg",{xmlns:"http://www.w3.org/2000/svg",version:"1.0",width:"159.000000pt",height:"160.000000pt",viewBox:"0 0 159.000000 160.000000",preserveAspectRatio:"xMidYMid meet"},Object(r.createElement)("g",{transform:"translate(0.000000,160.000000) scale(0.100000,-0.100000)",stroke:"none"},Object(r.createElement)("path",{fill:"#3575d3",d:"M310 1150 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M660 1150 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M1000 1150 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M310 800 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M660 800 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M1000 800 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M310 450 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M660 450 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}),Object(r.createElement)("path",{fill:"#3575d3",d:"M1000 450 l0 -140 140 0 140 0 0 140 0 140 -140 0 -140 0 0 -140z"}))),description:"Section that's built with the Bluehost Website Builder",category:"layout",supports:{align:["wide","full"],inserter:!1},attributes:{id:{type:"number"},align:{type:"string",default:"full"}},edit:function(e){var t=Object(r.useCallback)((function(){var e=window.wp.data.select("core/editor").getCurrentPost().id;window.location.assign("".concat(window.websiteBuilder.root,"wp-admin/admin.php?page=wb4wp-editor&wb4wp-post-id=").concat(e))}),[]),n=null;return window.wp.data.select("core/block-editor").getBlock(e.clientId).innerBlocks[0]&&(n=(n=window.wp.data.select("core/block-editor").getBlock(e.clientId).innerBlocks[0].originalContent).replace(/kv-notify-inview/gi,"")),window.setTimeout((function(){var e=document.querySelectorAll(".kv-site *[data-src]");Array.from(e).forEach((function(e){e.style.backgroundImage="url("+e.dataset.srcNormal+")",e.removeAttribute("data-src")}));var t=document.querySelectorAll(".kv-site *[data-image]");Array.from(t).forEach((function(e){e.setAttribute("style",e.getAttribute("style")+";"+e.dataset.image),e.removeAttribute("data-image")}))}),1),Object(r.createElement)("div",{className:"block-generic-wb4wp-content express-block-wrapper"},Object(r.createElement)("div",{className:"kv-main kv-site express-block",dangerouslySetInnerHTML:{__html:n}}),Object(r.createElement)("div",{className:"express-block-button"},Object(r.createElement)(o.Button,{isPrimary:!0,isLarge:!0,onClick:t},"Edit in Website Builder")))},save:function(){return Object(r.createElement)(l.InnerBlocks.Content,null)}})},5:function(e,t){!function(){e.exports=this.wp.blockEditor}()},7:function(e,t){!function(){e.exports=this.wp.components}()},8:function(e,t){!function(){e.exports=this.wp.blocks}()}});