<?php


namespace Wb4Wp\Helpers;

/**
 * Class Object_Helper
 * @package Wb4Wp\Helpers
 */
class Object_Helper {

	public static function get_property( &$property, $default = null ) {
		return isset( $property ) ? $property : $default;
	}

}
