<?php return array(
    'root' => array(
        'pretty_version' => '2.8.1',
        'version' => '2.8.1.0',
        'type' => 'wordpress-plugin',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'reference' => '23ee23e5fc9291e6cdab6fadd48005434bbe44ef',
        'name' => 'bluehost/bluehost-wordpress-plugin',
        'dev' => false,
    ),
    'versions' => array(
        'bluehost/bluehost-wordpress-plugin' => array(
            'pretty_version' => '2.8.1',
            'version' => '2.8.1.0',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'reference' => '23ee23e5fc9291e6cdab6fadd48005434bbe44ef',
            'dev_requirement' => false,
        ),
        'bluehost/endurance-wp-module-business-reviews' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bluehost/endurance-wp-module-business-reviews',
            'aliases' => array(),
            'reference' => '05ecf887a98c95642ae845bafd7be5b609304763',
            'dev_requirement' => false,
        ),
        'bluehost/endurance-wp-module-gutenframe' => array(
            'pretty_version' => '0.1.3',
            'version' => '0.1.3.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bluehost/endurance-wp-module-gutenframe',
            'aliases' => array(),
            'reference' => '6e3041b1abcb725de78f6cdc4c9ec6e09c9fadb9',
            'dev_requirement' => false,
        ),
        'bluehost/endurance-wp-module-loader' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bluehost/endurance-wp-module-loader',
            'aliases' => array(),
            'reference' => 'a9a384596e26950466f7ffc667e0be29f96c36a9',
            'dev_requirement' => false,
        ),
        'bluehost/endurance-wp-module-sso' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bluehost/endurance-wp-module-sso',
            'aliases' => array(),
            'reference' => 'f41f81721a175667cc87973f73a5f7a3d10a79d3',
            'dev_requirement' => false,
        ),
        'bluehost/endurance-wp-plugin-updater' => array(
            'pretty_version' => '1.1.2',
            'version' => '1.1.2.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bluehost/endurance-wp-plugin-updater',
            'aliases' => array(),
            'reference' => '7ba33e3f02d612aa5e5e25751c945d6c700d1653',
            'dev_requirement' => false,
        ),
        'doctrine/inflector' => array(
            'pretty_version' => '1.4.4',
            'version' => '1.4.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/inflector',
            'aliases' => array(),
            'reference' => '4bd5c1cdfcd00e9e2d8c484f79150f67e5d355d9',
            'dev_requirement' => false,
        ),
        'endurance/wp-module-data' => array(
            'pretty_version' => '1.4.3',
            'version' => '1.4.3.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../endurance/wp-module-data',
            'aliases' => array(),
            'reference' => '115be3fbc61dd026b230c56756da69d281316f18',
            'dev_requirement' => false,
        ),
        'pimple/pimple' => array(
            'pretty_version' => 'v3.4.0',
            'version' => '3.4.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pimple/pimple',
            'aliases' => array(),
            'reference' => '86406047271859ffc13424a048541f4531f53601',
            'dev_requirement' => false,
        ),
        'psr/container' => array(
            'pretty_version' => '1.1.1',
            'version' => '1.1.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/container',
            'aliases' => array(),
            'reference' => '8622567409010282b7aeebe4bb841fe98b58dcaf',
            'dev_requirement' => false,
        ),
        'wp-forge/helpers' => array(
            'pretty_version' => '1.0',
            'version' => '1.0.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wp-forge/helpers',
            'aliases' => array(),
            'reference' => 'a442941e3b7152045800d0a06cca016f0358bc21',
            'dev_requirement' => false,
        ),
        'wpscholar/collection' => array(
            'pretty_version' => '1.0',
            'version' => '1.0.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wpscholar/collection',
            'aliases' => array(),
            'reference' => 'f26360300a786a15532f9a4b1cababf639bec10e',
            'dev_requirement' => false,
        ),
        'wpscholar/url' => array(
            'pretty_version' => '1.2.2',
            'version' => '1.2.2.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wpscholar/url',
            'aliases' => array(),
            'reference' => 'c339972ed8e6876f1cfacbc512c6205db63645d0',
            'dev_requirement' => false,
        ),
    ),
);
