<?php

namespace Wb4Wp\Constants;

/**
 * Class ProviderNames
 *
 * @package Wb4Wp\Constants
 */
final class Provider_Names {

	const WB4WP          = 'wb4wp';
	const BLUEHOST       = 'bluehost';
	const BLUEHOST_INDIA = 'bluehost_in';
	const BLUEHOST_ASIA  = 'bluehost_asia';
}
