<?php
// phpcs:disable

namespace Wb4WpTheme\Managers\Customize;

/**
 * @deprecated Class CustomizeSettings
 * @package Wb4WpTheme\Managers\Customize
 */
class CustomizeSettings extends Customize_Settings {
}
