<?php return array (
  'root' => 
  array (
    'pretty_version' => 'dev-master',
    'version' => 'dev-master',
    'aliases' => 
    array (
    ),
    'reference' => NULL,
    'name' => 'automattic/jetpack',
  ),
  'versions' => 
  array (
    'automattic/jetpack' => 
    array (
      'pretty_version' => 'dev-master',
      'version' => 'dev-master',
      'aliases' => 
      array (
      ),
      'reference' => NULL,
    ),
    'automattic/jetpack-a8c-mc-stats' => 
    array (
      'pretty_version' => 'v1.4.4',
      'version' => '1.4.4.0',
      'aliases' => 
      array (
      ),
      'reference' => '59df714196e8ac4fd69a4ddedcb9dbeb12e7ecb5',
    ),
    'automattic/jetpack-abtest' => 
    array (
      'pretty_version' => 'v1.9.9',
      'version' => '1.9.9.0',
      'aliases' => 
      array (
      ),
      'reference' => '426a5e252ccab742af8c58cdcf16c8367c16a3a3',
    ),
    'automattic/jetpack-assets' => 
    array (
      'pretty_version' => 'v1.11.5',
      'version' => '1.11.5.0',
      'aliases' => 
      array (
      ),
      'reference' => '88f04c6eb63ee4ce801735c03f7db5cae05e79bc',
    ),
    'automattic/jetpack-autoloader' => 
    array (
      'pretty_version' => 'v2.10.3',
      'version' => '2.10.3.0',
      'aliases' => 
      array (
      ),
      'reference' => 'aab966d6f2c8fd6669d6f5b1378d8ced5fd665b4',
    ),
    'automattic/jetpack-backup' => 
    array (
      'pretty_version' => 'v1.1.1',
      'version' => '1.1.1.0',
      'aliases' => 
      array (
      ),
      'reference' => '1ec002e2e621218ac27fb07faae0ce52727a6816',
    ),
    'automattic/jetpack-blocks' => 
    array (
      'pretty_version' => 'v1.4.1',
      'version' => '1.4.1.0',
      'aliases' => 
      array (
      ),
      'reference' => '2d8e214bb64856cc4e2413af2e3252c241c668ca',
    ),
    'automattic/jetpack-compat' => 
    array (
      'pretty_version' => 'v1.6.5',
      'version' => '1.6.5.0',
      'aliases' => 
      array (
      ),
      'reference' => '8101adbec7971bae8746108a6fd261afae99524c',
    ),
    'automattic/jetpack-config' => 
    array (
      'pretty_version' => 'v1.4.6',
      'version' => '1.4.6.0',
      'aliases' => 
      array (
      ),
      'reference' => '98f8080550901a8a29daf466ee75a4906c5f1ef0',
    ),
    'automattic/jetpack-connection' => 
    array (
      'pretty_version' => 'v1.30.1',
      'version' => '1.30.1.0',
      'aliases' => 
      array (
      ),
      'reference' => 'c73a279ff07bdd343c8129ca40f56a6eb2b9273c',
    ),
    'automattic/jetpack-connection-ui' => 
    array (
      'pretty_version' => 'v1.3.0',
      'version' => '1.3.0.0',
      'aliases' => 
      array (
      ),
      'reference' => 'a6ce83b175600073786753bf79a9cd6f793dc334',
    ),
    'automattic/jetpack-constants' => 
    array (
      'pretty_version' => 'v1.6.5',
      'version' => '1.6.5.0',
      'aliases' => 
      array (
      ),
      'reference' => '1e02eebb828c6701f3bf97fa8404e9fc85d3fb63',
    ),
    'automattic/jetpack-device-detection' => 
    array (
      'pretty_version' => 'v1.4.2',
      'version' => '1.4.2.0',
      'aliases' => 
      array (
      ),
      'reference' => '6f7c0560cac114a99066a703cf66813e325e8630',
    ),
    'automattic/jetpack-error' => 
    array (
      'pretty_version' => 'v1.3.5',
      'version' => '1.3.5.0',
      'aliases' => 
      array (
      ),
      'reference' => 'f81fa17c2afb559dd12c52dae8aedb44da6a4195',
    ),
    'automattic/jetpack-heartbeat' => 
    array (
      'pretty_version' => 'v1.3.8',
      'version' => '1.3.8.0',
      'aliases' => 
      array (
      ),
      'reference' => 'ed630c4a9271d5ce2bba15eec4ff32c448330b67',
    ),
    'automattic/jetpack-identity-crisis' => 
    array (
      'pretty_version' => 'v0.2.2',
      'version' => '0.2.2.0',
      'aliases' => 
      array (
      ),
      'reference' => 'f9e76478f8df130238f0843fd53472fff0b7e76e',
    ),
    'automattic/jetpack-jitm' => 
    array (
      'pretty_version' => 'v1.16.2',
      'version' => '1.16.2.0',
      'aliases' => 
      array (
      ),
      'reference' => '3276a4cf55b739c8c42448fd33f16f26ab766aaa',
    ),
    'automattic/jetpack-lazy-images' => 
    array (
      'pretty_version' => 'v1.5.0',
      'version' => '1.5.0.0',
      'aliases' => 
      array (
      ),
      'reference' => '27d9a86239c61093557d9256bf9d46e589b384cc',
    ),
    'automattic/jetpack-licensing' => 
    array (
      'pretty_version' => 'v1.4.4',
      'version' => '1.4.4.0',
      'aliases' => 
      array (
      ),
      'reference' => '1355affaf0dabb72a55a75ed89159e567e458a20',
    ),
    'automattic/jetpack-logo' => 
    array (
      'pretty_version' => 'v1.5.5',
      'version' => '1.5.5.0',
      'aliases' => 
      array (
      ),
      'reference' => '4b4a24e30ac76beea19a4d75b451e2b7a287db4c',
    ),
    'automattic/jetpack-options' => 
    array (
      'pretty_version' => 'v1.13.0',
      'version' => '1.13.0.0',
      'aliases' => 
      array (
      ),
      'reference' => '2606ae27f9b4336ca1b34ee9ecd99ac658ef30fc',
    ),
    'automattic/jetpack-partner' => 
    array (
      'pretty_version' => 'v1.5.1',
      'version' => '1.5.1.0',
      'aliases' => 
      array (
      ),
      'reference' => 'c5836805d2dd2367264408260d1f51a0a82a0203',
    ),
    'automattic/jetpack-password-checker' => 
    array (
      'pretty_version' => 'v0.1.2',
      'version' => '0.1.2.0',
      'aliases' => 
      array (
      ),
      'reference' => '408bf765942578276da69b10c2600564773dceee',
    ),
    'automattic/jetpack-redirect' => 
    array (
      'pretty_version' => 'v1.7.0',
      'version' => '1.7.0.0',
      'aliases' => 
      array (
      ),
      'reference' => '8320a82f8daee5127a2c3e19cb4e2566ba4c94bb',
    ),
    'automattic/jetpack-roles' => 
    array (
      'pretty_version' => 'v1.4.5',
      'version' => '1.4.5.0',
      'aliases' => 
      array (
      ),
      'reference' => 'd04bbd4e012516d280a610e3961edef5cf241722',
    ),
    'automattic/jetpack-status' => 
    array (
      'pretty_version' => 'v1.8.0',
      'version' => '1.8.0.0',
      'aliases' => 
      array (
      ),
      'reference' => '9da88ee253d69e4948c76e4080435aca23c65dbb',
    ),
    'automattic/jetpack-sync' => 
    array (
      'pretty_version' => 'v1.24.2',
      'version' => '1.24.2.0',
      'aliases' => 
      array (
      ),
      'reference' => '08ddb52e2118daa59541dadedb87a25febf12ef5',
    ),
    'automattic/jetpack-terms-of-service' => 
    array (
      'pretty_version' => 'v1.9.8',
      'version' => '1.9.8.0',
      'aliases' => 
      array (
      ),
      'reference' => '9ebb094dc1243b36c449ecb37a858511c9b41759',
    ),
    'automattic/jetpack-tracking' => 
    array (
      'pretty_version' => 'v1.13.7',
      'version' => '1.13.7.0',
      'aliases' => 
      array (
      ),
      'reference' => '8fd3b9aef38dd2dd9b072dfd9af5b9a3278b20b6',
    ),
    'nojimage/twitter-text-php' => 
    array (
      'pretty_version' => 'v3.1.2',
      'version' => '3.1.2.0',
      'aliases' => 
      array (
      ),
      'reference' => '979bcf6a92d543b61588c7c0c0a87d0eb473d8f6',
    ),
  ),
);
