<?php
// phpcs:disable

namespace Wb4WpTheme\Managers\Customize;

/**
 * @deprecated Class CustomizeControls
 * @package Wb4WpTheme\Managers\Customize
 */
class CustomizeControls extends Customize_Controls {
}
