<?php // @codingStandardsIgnoreStart

use Wb4WpTheme\Managers\Customize\Customize_Settings;

?>

<address>
	<p class="wb4wp-copy">
		<?php echo ! empty( Customize_Settings::get_setting( 'wb4wp_contact_information_section_street_setting' ) ) ? Customize_Settings::get_setting( 'wb4wp_contact_information_section_street_setting' ) : ''; ?>
		<br>
		<?php echo ! empty( Customize_Settings::get_setting( 'wb4wp_contact_information_section_city_setting' ) ) ? Customize_Settings::get_setting( 'wb4wp_contact_information_section_city_setting' ) . ',': ''; ?>
		<?php echo ! empty( Customize_Settings::get_setting( 'wb4wp_contact_information_section_state_setting' ) ) ? Customize_Settings::get_setting( 'wb4wp_contact_information_section_state_setting' ) . ',' : ''; ?>
		<?php echo ! empty( Customize_Settings::get_setting( 'wb4wp_contact_information_section_zip_code_setting' ) ) ? Customize_Settings::get_setting( 'wb4wp_contact_information_section_zip_code_setting' ) . ',' : ''; ?>
		<?php echo ! empty( Customize_Settings::get_setting( 'wb4wp_contact_information_section_country_setting' ) ) ? Customize_Settings::get_setting( 'wb4wp_contact_information_section_country_setting' ) . ',' : ''; ?>
	</p>
</address>
