/**
 * Colors
 */
/**
 * Breakpoints & Media Queries
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Dimensions.
 */
/**
 * Shadows.
 */
/**
 * Editor widths.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
 * Breakpoint mixins
 */
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
.wp-block-gallery li {
  list-style-type: none;
}
.wp-block-gallery .block-editor-media-placeholder.is-appender .components-placeholder__label {
  display: none;
}
.wp-block-gallery .block-editor-media-placeholder.is-appender .block-editor-media-placeholder__button {
  margin-bottom: 0;
}

figure.wp-block-gallery {
  display: block;
  margin: 0;
}

.blocks-gallery-grid.blocks-gallery-grid {
  padding-left: 0;
  margin-left: 0;
  margin-bottom: 0;
}

.blocks-gallery-item figure:not(.is-selected):focus,
.blocks-gallery-item img:focus {
  outline: none;
}
.blocks-gallery-item figure.is-selected::before {
  box-shadow: 0 0 0 1px #fff inset, 0 0 0 3px var(--wp-admin-theme-color) inset;
  content: "";
  outline: 2px solid transparent;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1;
  pointer-events: none;
}
.blocks-gallery-item figure.is-selected figcaption {
  z-index: 2;
}
.blocks-gallery-item figure.is-transient img {
  opacity: 0.3;
}
.blocks-gallery-item .is-selected .block-library-gallery-item__inline-menu {
  display: inline-flex;
}
.blocks-gallery-item .block-editor-media-placeholder {
  margin: 0;
  height: 100%;
}
.blocks-gallery-item .block-editor-media-placeholder .components-placeholder__label {
  display: flex;
}

.block-library-gallery-item__inline-menu {
  display: none;
  position: absolute;
  top: -2px;
  margin: 8px;
  z-index: 20;
  transition: box-shadow 0.2s ease-out;
  border-radius: 2px;
  background: #fff;
  border: 1px solid #1e1e1e;
}
@media (prefers-reduced-motion: reduce) {
  .block-library-gallery-item__inline-menu {
    transition-duration: 0s;
    transition-delay: 0s;
  }
}
.block-library-gallery-item__inline-menu:hover {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.05);
}
@media (min-width: 600px) {
  .columns-7 .block-library-gallery-item__inline-menu, .columns-8 .block-library-gallery-item__inline-menu {
    padding: 2px;
  }
}
.block-library-gallery-item__inline-menu .components-button.has-icon:not(:focus) {
  border: none;
  box-shadow: none;
}
@media (min-width: 600px) {
  .columns-7 .block-library-gallery-item__inline-menu .components-button.has-icon, .columns-8 .block-library-gallery-item__inline-menu .components-button.has-icon {
    padding: 0;
    width: inherit;
    height: inherit;
  }
}
.block-library-gallery-item__inline-menu.is-left {
  left: -2px;
}
.block-library-gallery-item__inline-menu.is-right {
  right: -2px;
}

.blocks-gallery-item .components-spinner {
  position: absolute;
  top: 50%;
  left: 50%;
  margin-top: -9px;
  margin-left: -9px;
}