<?php
namespace Raygun4php
{
    class RaygunMessageDetails
    {
        public $Error;
        public $MachineName;
        public $Request;
        public $Environment;
        public $Client;
        public $Version;
        public $Tags;
        public $UserCustomData;
        public $User;
        public $Context;
        public $GroupingKey;
    }
}
