.wp-block-jetpack-google-calendar{min-width:420px}.wp-block-jetpack-google-calendar iframe{width:100%;border:none}.wp-block-jetpack-google-calendar>amp-iframe>[placeholder]{line-height:1}.wp-block-jetpack-google-calendar>amp-iframe>noscript{display:inline-block!important}.wp-block-jetpack-google-calendar>amp-iframe>noscript>iframe{position:absolute;top:0;right:0;bottom:0;left:0;width:100%;height:100%;z-index:1}