<?php return array('buildHash' => 'ef22b2c66f473d3214a6', 'manifest' => array('app' => array('entry' => 'app', 'assets' => array('js' => array(array('filename' => 'manifest~app-320ed2c6cbeb124c1e41.js', 'kebab' => 'bwp-manifest-app', 'snake' => 'bwp_manifest_app', 'camel' => 'bwpManifestApp', 'dependencies' => array('lodash', 'react', 'react-dom', 'react-router-dom', 'wp-a11y', 'wp-api-fetch', 'wp-components', 'wp-compose', 'wp-data', 'wp-dom-ready', 'wp-element', 'wp-html-entities', 'wp-i18n', 'wp-keycodes', 'wp-polyfill', 'wp-url'), 'version' => '320ed2c6cbeb124c1e41627b9046df24'), array('filename' => 'vendors~app-110a6048cb19e7acab43.js', 'kebab' => 'bwp-vendors-app', 'snake' => 'bwp_vendors_app', 'camel' => 'bwpVendorsApp', 'dependencies' => array('bwp-manifest-app')), array('filename' => 'app-ff1d1e88f0ab4a9ed77c.js', 'kebab' => 'bwp-app', 'snake' => 'bwp_app', 'camel' => 'bwpApp', 'dependencies' => array('bwp-vendors-app'))), 'css' => array(array('filename' => 'app-ff1d1e88f0ab4a9ed77c.css', 'kebab' => 'bwp-app', 'snake' => 'bwp_app')))), 'dashboard' => array('entry' => 'dashboard', 'assets' => array('js' => array(array('filename' => 'manifest~dashboard-932752c5481901fb4cc4.js', 'kebab' => 'bwp-manifest-dashboard', 'snake' => 'bwp_manifest_dashboard', 'camel' => 'bwpManifestDashboard', 'dependencies' => array('react', 'wp-api-fetch', 'wp-dom-ready', 'wp-element', 'wp-i18n', 'wp-polyfill', 'wp-url'), 'version' => '932752c5481901fb4cc460518a1630de'), array('filename' => 'dashboard-4cdf14d5f19a26156080.js', 'kebab' => 'bwp-dashboard', 'snake' => 'bwp_dashboard', 'camel' => 'bwpDashboard', 'dependencies' => array('bwp-manifest-dashboard'))), 'css' => array(array('filename' => 'dashboard-4cdf14d5f19a26156080.css', 'kebab' => 'bwp-dashboard', 'snake' => 'bwp_dashboard')))), 'editortours' => array('entry' => 'editortours', 'assets' => array('js' => array(array('filename' => 'manifest~editortours-31b04ce032850adfdbc2.js', 'kebab' => 'bwp-manifest-editortours', 'snake' => 'bwp_manifest_editortours', 'camel' => 'bwpManifestEditortours', 'dependencies' => array('lodash', 'react', 'wp-api-fetch', 'wp-components', 'wp-data', 'wp-dom-ready', 'wp-edit-post', 'wp-element', 'wp-i18n', 'wp-plugins', 'wp-polyfill', 'wp-url'), 'version' => '31b04ce032850adfdbc25f8a595927f3'), array('filename' => 'editortours-13ce54175ae74adc74b5.js', 'kebab' => 'bwp-editortours', 'snake' => 'bwp_editortours', 'camel' => 'bwpEditortours', 'dependencies' => array('bwp-manifest-editortours'))), 'css' => array(array('filename' => 'editortours-13ce54175ae74adc74b5.css', 'kebab' => 'bwp-editortours', 'snake' => 'bwp_editortours'))))));