
@import "http://fonts.googleapis.com/css?family=PT+Sans:regular,italic,bold,bolditalic";

body {font-family:'PT Sans', Helvetica, Arial, sans-serif;font-size:12px;color:#222;padding:0;margin:0;overflow-x:hidden;background:#eee;}
p,div,table,tr,td,form,input { padding:0; margin:0; font-weight:normal; text-decoration:none; }
p { padding:8px 0; }

/* Links */
a { color:#1580AF; font-weight:bold; text-decoration:none; }
a:link { }
a:visited { }
a:active,a:focus { outline:0; }
a:hover { color:#F16529; font-weight:bold; text-decoration:none; }

/* Headings */
h1 { }
h2 { font-size: 28px; padding:16px 0 4px; margin:0; }
h3 { padding:0; margin:0; font-weight:normal; text-decoration:none; }
h4 { }
h5 { }
h6 { }

/* Listings */
ul { }
ul li { }
ol { }
ol li { }

/* Forms */
select,option { color:#111; font-weight:normal; text-decoration:none; font-size:12px; }
input { vertical-align:middle; font-size:12px; }
textarea { }
label { }

/* Images */
img { border:none; }

/* Horizontal lines */
hr { line-height:0; height:0; border:none; border-bottom:1px solid #ccc; padding:0; margin:8px 0; }
hr.separator { }

/* Other */
fieldset { }
legend { }
pre { font-family:monospace; }

/* ----------------- Layout ----------------- */

#topContainer {background:#222;padding:80px 0 40px;border-bottom:1px solid #999;text-align:center;}
	#topContainer h1 {color:#eee;padding:24px 0 16px;margin:0;font-size:52px;text-shadow: 0px 0px 4px #000;filter:dropshadow(color=#000, offx=0, offy=0);}
	#topContainer a {color:#eee;font-size:18px;display:block;background:#37AFEB;width:200px;padding:8px 16px;margin:20px auto;-moz-border-radius:8px;-webkit-border-radius:8px;border-radius:8px;-moz-box-shadow: 0 0 4px #000;-webkit-box-shadow: 0 0 4px #000;box-shadow: 0 0 4px #000;}
	#topContainer a:hover {background:#F16529;}
	#topContainer p {color:#eee;}
	#topContainer span#notice {font-style:italic;font-size:11px;color:#999;}
	
#socialTools {padding:16px 0;margin:0 auto;width:580px;}
	.stTwitter {float:left;width:130px;}
	.stFacebook {float:left;width:450px;}
			
#mainContainer { width:900px; margin:20px auto; padding:20px; background:#fff; border:1px solid #e0e0e0; }

#releaseNotes { padding:8px; background:#f1f1f1; line-height:20px; border:1px solid #ddd; }
	#releaseNotes ul { padding:4px 4px 4px 16px; margin:0; }

#credits { text-align:right; /*border-top:1px solid #e0e0e0;*/ padding:8px; margin:8px 0 0; }
