<?php
/**
 * The Package_Version class.
 *
 * @package automattic/jetpack-sync
 */

namespace Automattic\Jetpack\Sync;

/**
 * The Package_Version class.
 */
class Package_Version {

	const PACKAGE_VERSION = '1.24.2';
}
