<?php

namespace Wb4Wp\Constants;

/**
 * Class ThemeConstants
 *
 * @package Wb4Wp\Constants
 */
final class Theme_Constants {

	const THEME_NAME      = 'wb4wp-wordpress-theme';
	const THEME_MODS_NAME = 'theme_mods_' . self::THEME_NAME;
}
