<?php

// autoload_files.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    '637fa4e5a9fe2956d844ead1daab0f31' => $vendorDir . '/bluehost/endurance-wp-module-business-reviews/bootstrap.php',
    '0774e44945781cd5a8d0b0dc32f80615' => $vendorDir . '/bluehost/endurance-wp-module-gutenframe/bootstrap.php',
    '0a7ee76a6dd15c6349ed695bd3b2a987' => $vendorDir . '/bluehost/endurance-wp-module-loader/module-loader.php',
    '6e09b332987211bb2939025b3ed3c51b' => $vendorDir . '/bluehost/endurance-wp-module-sso/bootstrap.php',
    'b62570ec8ed5d9ce1990d98269e51fa3' => $vendorDir . '/endurance/wp-module-data/bootstrap.php',
);
