.jp-dashboard-footer {
  display: flex;
  flex-flow: row wrap;
  justify-content: space-between;
  align-items: center;
  width: 100%;
  max-width: 65rem;
  color: #000; }
  @media (max-width: 1250px) {
    .jp-dashboard-footer {
      width: 95%; } }
  @media (max-width: 480px) {
    .jp-dashboard-footer {
      justify-content: space-around; } }

.jp-dashboard-footer__module-name,
.jp-dashboard-footer__jetpack-symbol {
  vertical-align: middle;
  display: inline-block; }

.jp-dashboard-footer__module-name {
  margin-left: 5px; }

.jp-connect-button .jp-connect-button--button {
  background: #000;
  border-radius: 4px;
  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', 'Oxygen-Sans', 'Ubuntu', 'Cantarell', 'Helvetica Neue', sans-serif;
  font-style: normal;
  font-weight: 600;
  font-size: 14px;
  line-height: 18px;
  text-align: center;
  width: 264px;
  height: 40px;
  display: block; }

.jp-connect-screen {
  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', 'Oxygen-Sans', 'Ubuntu', 'Cantarell', 'Helvetica Neue', sans-serif;
  background: #FFFFFF;
  box-shadow: 0 0 40px rgba(0, 0, 0, 0.08);
  border-radius: 4px; }
  .jp-connect-screen.jp-connect-screen--loading {
    display: none; }
  .jp-connect-screen .jp-connect-screen--left, .jp-connect-screen .jp-connect-screen--right {
    box-sizing: border-box; }
  .jp-connect-screen .jp-connect-screen--left {
    padding: 64px 96px; }
    .jp-connect-screen .jp-connect-screen--left h2 {
      font-style: normal;
      font-weight: bold;
      font-size: 36px;
      line-height: 40px;
      color: #000; }
    .jp-connect-screen .jp-connect-screen--left p, .jp-connect-screen .jp-connect-screen--left li {
      font-style: normal;
      font-weight: normal;
      font-size: 16px;
      line-height: 24px; }
    .jp-connect-screen .jp-connect-screen--left p {
      color: #101517; }
    .jp-connect-screen .jp-connect-screen--left ul {
      list-style-type: none; }
      .jp-connect-screen .jp-connect-screen--left ul li {
        background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAACXBIWXMAAAsTAAALEwEAmpwYAAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAADuSURBVHgB7ZS9DYJAFIDfHT93JSMwAiPoAmhpR22lTqBbmJggbqCyAJZ0xg1YwQ4MeB5GjPIT8KCTL6Hhke9LHgcAPT2NcahOHDLL35agC7hcZeABoIlsStfETfxshKEtbzno/ArQDR0+xwjakJPjCIbhNAy6CTSQp4ityNE0FdC+Tl4eWFMdauWRB4wZdfJiYKMYCmFnZUutLuSFAJHkAQKk8RezK0QE5Clf30Hixr5kyrwBPARjPJKD+zG+iMpTSk+RatMVnyyfDzC2YBhbIvLKQD7y4md5SuWvgq/rlK1LVN4IYpM5rTu6Pf/NA02TfHxOAFa6AAAAAElFTkSuQmCC) no-repeat;
        padding-left: 30px;
        color: #000;
        margin-bottom: 9px; }
    .jp-connect-screen .jp-connect-screen--left .jp-connect-button {
      margin-top: 40px; }
    .jp-connect-screen .jp-connect-screen--left .jp-connnect-screen--tos {
      margin-top: 32px;
      max-width: 360px; }
  .jp-connect-screen .jp-connect-screen--right {
    padding: 64px 0; }
    .jp-connect-screen .jp-connect-screen--right img {
      max-width: 100%; }
  .jp-connect-screen.jp-connect-screen--two-columns .jp-connect-screen--left {
    float: left;
    width: 50%; }
  .jp-connect-screen.jp-connect-screen--two-columns .jp-connect-screen--right {
    float: right;
    width: 49%;
    background: #F9F9F6; }
  .jp-connect-screen .jp-connect-screen--clearfix {
    clear: both; }

.jp-iframe-wrap {
  text-align: center; }

.fade-in {
  animation: fadeIn ease 1.5s;
  -webkit-animation: fadeIn ease 1.5s;
  -moz-animation: fadeIn ease 1.5s;
  -o-animation: fadeIn ease 1.5s;
  -ms-animation: fadeIn ease 1.5s; }

@keyframes fadeIn {
  0% {
    opacity: 0; }
  100% {
    opacity: 1; } }

@-webkit-keyframes fadeIn {
  0% {
    opacity: 0; }
  100% {
    opacity: 1; } }

@charset "UTF-8";
/********* RNA styles *********/
:root {
  --font-title-large: 36px;
  --font-title-small: 24px;
  --font-body: 16px;
  --font-label: 12px;
  --jp-black:           #000000;
  --jp-black-80:        #2C3338;
  --jp-white:           #FFFFFF;
  --jp-white-off:       #F9F9F6;
  --jp-gray:            #DCDCDE;
  --jp-gray-off:        #E2E2DF;
  --jp-red:             #D63639;
  --jp-green-primary:   #069E08;
  --jp-green-secondary: #2FB41F;
  --jp-border-radius: 4px;
  --jp-menu-border-height: 1px;
  --jp-underline-thickness: 2px; }

/********* Mixins *********/
/********* Generic styles *********/
* {
  box-sizing: border-box; }

body {
  min-height: 100%;
  margin: 0;
  padding: 0;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen-Sans", "Ubuntu", "Cantarell", "Helvetica Neue", sans-serif; }

.jp-wrap {
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  max-width: 1128px;
  margin: 0 auto; }

.jp-row {
  display: grid;
  grid-gap: 24px;
  grid-template-columns: repeat(4, 1fr);
  width: 100%;
  margin: 0 16px; }
  @media (min-width: 600px) {
    .jp-row {
      grid-template-columns: repeat(8, 1fr);
      margin: 0 18px; } }
  @media (min-width: 960px) {
    .jp-row {
      grid-template-columns: repeat(12, 1fr);
      max-width: 1128px;
      margin: 0 24px; } }

.sm-col-span-1 {
  grid-column-end: span 1; }

.sm-col-span-2 {
  grid-column-end: span 2; }

.sm-col-span-3 {
  grid-column-end: span 3; }

.sm-col-span-4 {
  grid-column-end: span 4; }

@media (min-width: 600px) {
  .md-col-span-1 {
    grid-column-end: span 1; }
  .md-col-span-2 {
    grid-column-end: span 2; }
  .md-col-span-3 {
    grid-column-end: span 3; }
  .md-col-span-4 {
    grid-column-end: span 4; }
  .md-col-span-5 {
    grid-column-end: span 5; }
  .md-col-span-6 {
    grid-column-end: span 6; }
  .md-col-span-7 {
    grid-column-end: span 7; }
  .md-col-span-8 {
    grid-column-end: span 8; } }

@media (min-width: 960px) {
  .lg-col-span-1 {
    grid-column-end: span 1; }
  .lg-col-span-2 {
    grid-column-end: span 2; }
  .lg-col-span-3 {
    grid-column-end: span 3; }
  .lg-col-span-4 {
    grid-column-end: span 4; }
  .lg-col-span-5 {
    grid-column-end: span 5; }
  .lg-col-span-6 {
    grid-column-end: span 6; }
  .lg-col-span-7 {
    grid-column-end: span 7; }
  .lg-col-span-8 {
    grid-column-end: span 8; }
  .lg-col-span-9 {
    grid-column-end: span 9; }
  .lg-col-span-10 {
    grid-column-end: span 10; }
  .lg-col-span-11 {
    grid-column-end: span 11; }
  .lg-col-span-12 {
    grid-column-end: span 12; } }

@media (max-width: 960px) {
  .md-col-span-0 {
    display: none; } }

@media (max-width: 600px) {
  .sm-col-span-0 {
    display: none; } }

.jp-wrap {
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  max-width: 1128px;
  margin: 0 auto; }

.jp-row {
  display: grid;
  grid-gap: 24px;
  grid-template-columns: repeat(4, 1fr);
  width: 100%;
  margin: 0 16px; }
  @media (min-width: 600px) {
    .jp-row {
      grid-template-columns: repeat(8, 1fr);
      margin: 0 18px; } }
  @media (min-width: 960px) {
    .jp-row {
      grid-template-columns: repeat(12, 1fr);
      max-width: 1128px;
      margin: 0 24px; } }

.jp-cut {
  position: relative;
  display: block;
  margin: 32px 0;
  padding: 16px 64px 16px 24px;
  border: 2px solid #069E08;
  border: 2px solid var(--jp-green-primary);
  border-radius: 4px;
  border-radius: var(--jp-border-radius);
  text-decoration: none; }
  .jp-cut span {
    display: block; }
    .jp-cut span:last-of-type {
      font-weight: 600; }
  .jp-cut:hover span:last-of-type, .jp-cut:focus span:last-of-type {
    text-decoration: underline;
    text-decoration-thickness: 2px;
    text-decoration-thickness: var(--jp-underline-thickness); }
  .jp-cut:hover:after, .jp-cut:focus:after {
    transform: translateY(-50%) translateX(8px); }
  .jp-cut:after {
    content: "→";
    position: absolute;
    top: 50%;
    right: 24px;
    font-size: 24px;
    font-weight: 600;
    color: #069E08;
    color: var(--jp-green-primary);
    transform: translateY(-50%);
    transition: transform 0.15s ease-out; }

.jp-disconnect-dialog h1 {
  margin-top: 0;
  line-height: 1.2;
  font-size: 36px;
  font-size: var(--font-title-large);
  font-weight: 600; }

.jp-disconnect-dialog h2 {
  margin: 0;
  line-height: 1.2;
  font-size: 24px;
  font-size: var(--font-title-small);
  font-weight: 400; }

.jp-disconnect-dialog p {
  font-size: 16px;
  font-size: var(--font-body); }

.jp-disconnect-dialog__link {
  font-size: 16px;
  font-size: var(--font-body);
  color: #000000;
  color: var(--jp-black);
  text-decoration: underline;
  height: auto;
  font: inherit;
  padding: 0; }
  .jp-disconnect-dialog__link:hover {
    color: #000000;
    color: var(--jp-black);
    text-decoration-thickness: 2px;
    text-decoration-thickness: var(--jp-underline-thickness); }
  .jp-disconnect-dialog__link:focus {
    color: #000000;
    color: var(--jp-black);
    box-shadow: none !important; }

.jp-disconnect-dialog .components-button {
  height: 40px;
  font-size: var(--font-body-small);
  border-radius: 4px; }

.jp-disconnect-dialog .components-modal__content {
  padding: 0; }

.jp-disconnect-dialog .components-modal__header {
  display: none; }

.jp-disconnect-dialog .jp-row {
  align-items: center; }

.jp-disconnect-dialog__content {
  background: #F9F9F6;
  background: var(--jp-white-off);
  margin: 0;
  padding: 80px;
  border-radius: 4px;
  text-align: center; }

.jp-disconnect-dialog__actions {
  background: #FFFFFF;
  background: var(--jp-white);
  padding: 10px 48px; }

.jp-disconnect-dialog__btn-dismiss {
  background: #000000 !important;
  background: var(--jp-black) !important;
  margin-right: 10px; }

.jp-disconnect-dialog__btn-disconnect {
  background: #D63639 !important;
  background: var(--jp-red) !important; }

.jp-disconnect-dialog__btn-back-to-wp {
  background: #000000 !important;
  background: var(--jp-black) !important; }

.jp-disconnect-dialog__button-wrap {
  text-align: center; }

.jp-disconnect-dialog__error {
  color: #D63639;
  color: var(--jp-red); }

.jp-disconnect-dialog__success .components-modal__content {
  background: #FFFFFF;
  background: var(--jp-white);
  padding: 50px; }

.jp-disconnect-dialog__success h1 {
  margin-top: 20px; }

@media (min-width: 960px) {
  .jp-disconnect-dialog {
    min-width: 900px; }
    .jp-disconnect-dialog__success {
      min-width: auto; }
  .jp-row {
    margin-left: 0px; } }

@charset "UTF-8";
/********* RNA styles *********/
:root {
  --font-title-large: 36px;
  --font-title-small: 24px;
  --font-body: 16px;
  --font-label: 12px;
  --jp-black:           #000000;
  --jp-black-80:        #2C3338;
  --jp-white:           #FFFFFF;
  --jp-white-off:       #F9F9F6;
  --jp-gray:            #DCDCDE;
  --jp-gray-off:        #E2E2DF;
  --jp-red:             #D63639;
  --jp-green-primary:   #069E08;
  --jp-green-secondary: #2FB41F;
  --jp-border-radius: 4px;
  --jp-menu-border-height: 1px;
  --jp-underline-thickness: 2px; }

/********* Mixins *********/
/********* Generic styles *********/
* {
  box-sizing: border-box; }

body {
  min-height: 100%;
  margin: 0;
  padding: 0;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen-Sans", "Ubuntu", "Cantarell", "Helvetica Neue", sans-serif; }

.jp-wrap {
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  max-width: 1128px;
  margin: 0 auto; }

.jp-row {
  display: grid;
  grid-gap: 24px;
  grid-template-columns: repeat(4, 1fr);
  width: 100%;
  margin: 0 16px; }
  @media (min-width: 600px) {
    .jp-row {
      grid-template-columns: repeat(8, 1fr);
      margin: 0 18px; } }
  @media (min-width: 960px) {
    .jp-row {
      grid-template-columns: repeat(12, 1fr);
      max-width: 1128px;
      margin: 0 24px; } }

.sm-col-span-1 {
  grid-column-end: span 1; }

.sm-col-span-2 {
  grid-column-end: span 2; }

.sm-col-span-3 {
  grid-column-end: span 3; }

.sm-col-span-4 {
  grid-column-end: span 4; }

@media (min-width: 600px) {
  .md-col-span-1 {
    grid-column-end: span 1; }
  .md-col-span-2 {
    grid-column-end: span 2; }
  .md-col-span-3 {
    grid-column-end: span 3; }
  .md-col-span-4 {
    grid-column-end: span 4; }
  .md-col-span-5 {
    grid-column-end: span 5; }
  .md-col-span-6 {
    grid-column-end: span 6; }
  .md-col-span-7 {
    grid-column-end: span 7; }
  .md-col-span-8 {
    grid-column-end: span 8; } }

@media (min-width: 960px) {
  .lg-col-span-1 {
    grid-column-end: span 1; }
  .lg-col-span-2 {
    grid-column-end: span 2; }
  .lg-col-span-3 {
    grid-column-end: span 3; }
  .lg-col-span-4 {
    grid-column-end: span 4; }
  .lg-col-span-5 {
    grid-column-end: span 5; }
  .lg-col-span-6 {
    grid-column-end: span 6; }
  .lg-col-span-7 {
    grid-column-end: span 7; }
  .lg-col-span-8 {
    grid-column-end: span 8; }
  .lg-col-span-9 {
    grid-column-end: span 9; }
  .lg-col-span-10 {
    grid-column-end: span 10; }
  .lg-col-span-11 {
    grid-column-end: span 11; }
  .lg-col-span-12 {
    grid-column-end: span 12; } }

@media (max-width: 960px) {
  .md-col-span-0 {
    display: none; } }

@media (max-width: 600px) {
  .sm-col-span-0 {
    display: none; } }

.jp-wrap {
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  max-width: 1128px;
  margin: 0 auto; }

.jp-row {
  display: grid;
  grid-gap: 24px;
  grid-template-columns: repeat(4, 1fr);
  width: 100%;
  margin: 0 16px; }
  @media (min-width: 600px) {
    .jp-row {
      grid-template-columns: repeat(8, 1fr);
      margin: 0 18px; } }
  @media (min-width: 960px) {
    .jp-row {
      grid-template-columns: repeat(12, 1fr);
      max-width: 1128px;
      margin: 0 24px; } }

.jp-cut {
  position: relative;
  display: block;
  margin: 32px 0;
  padding: 16px 64px 16px 24px;
  border: 2px solid #069E08;
  border: 2px solid var(--jp-green-primary);
  border-radius: 4px;
  border-radius: var(--jp-border-radius);
  text-decoration: none; }
  .jp-cut span {
    display: block; }
    .jp-cut span:last-of-type {
      font-weight: 600; }
  .jp-cut:hover span:last-of-type, .jp-cut:focus span:last-of-type {
    text-decoration: underline;
    text-decoration-thickness: 2px;
    text-decoration-thickness: var(--jp-underline-thickness); }
  .jp-cut:hover:after, .jp-cut:focus:after {
    transform: translateY(-50%) translateX(8px); }
  .jp-cut:after {
    content: "→";
    position: absolute;
    top: 50%;
    right: 24px;
    font-size: 24px;
    font-weight: 600;
    color: #069E08;
    color: var(--jp-green-primary);
    transform: translateY(-50%);
    transition: transform 0.15s ease-out; }

.jp-connection-status-card h3 {
  font-size: 36px;
  line-height: 40px; }

.jp-connection-status-card a, .jp-connection-status-card a:active, .jp-connection-status-card a:hover {
  color: #000000;
  color: var(--jp-black); }

.jp-connection-status-card p {
  margin: 16px 0; }

.jp-connection-status-card p, .jp-connection-status-card a, .jp-connection-status-card li {
  font-size: 16px;
  line-height: 24px; }

.jp-connection-status-card--status {
  display: flex;
  align-items: center; }

.jp-connection-status-card--cloud {
  background-image: url("data:image/svg+xml;base64,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");
  width: 42px;
  height: 42px;
  margin-right: 4px; }

.jp-connection-status-card--jetpack-logo {
  background-image: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMzIiIGhlaWdodD0iMzIiIHZpZXdCb3g9IjAgMCAzMiAzMiIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPHBhdGggZD0iTTE2IDMyQzI0LjgzNjYgMzIgMzIgMjQuODM2NiAzMiAxNkMzMiA3LjE2MzQ0IDI0LjgzNjYgMCAxNiAwQzcuMTYzNDQgMCAwIDcuMTYzNDQgMCAxNkMwIDI0LjgzNjYgNy4xNjM0NCAzMiAxNiAzMloiIGZpbGw9ImJsYWNrIi8+CjxwYXRoIGQ9Ik0xNi43OTM5IDEzLjMxMjVWMjguODI0TDI0Ljc5MzkgMTMuMzEyNUgxNi43OTM5WiIgZmlsbD0id2hpdGUiLz4KPHBhdGggZD0iTTE1LjE3NTUgMTguNjU2N1YzLjE3NTc4TDcuMjA2MDUgMTguNjU2N0gxNS4xNzU1WiIgZmlsbD0id2hpdGUiLz4KPC9zdmc+Cg==");
  width: 32px;
  height: 32px;
  margin-left: 11px; }

.jp-connection-status-card--btn-connect-user {
  height: 40px;
  font-size: var(--font-body-small);
  border-radius: 4px;
  background: #000000 !important;
  background: var(--jp-black) !important; }

.jp-connection-status-card--avatar {
  border: 0;
  border-radius: 20px;
  width: 32px;
  height: 32px;
  background-color: #FFFFFF;
  background-color: var(--jp-white);
  background-repeat: no-repeat;
  background-size: contain;
  margin-left: -10px;
  background-image: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjUiIGhlaWdodD0iMjQiIHZpZXdCb3g9IjAgMCAyNSAyNCIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPG1hc2sgaWQ9Im1hc2swIiBtYXNrLXR5cGU9ImFscGhhIiBtYXNrVW5pdHM9InVzZXJTcGFjZU9uVXNlIiB4PSI0IiB5PSI0IiB3aWR0aD0iMTciIGhlaWdodD0iMTYiPgo8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGNsaXAtcnVsZT0iZXZlbm9kZCIgZD0iTTEyLjI4NSA0QzEwLjA4NTggNCA4LjMwNDU5IDUuNzkgOC4zMDQ1OSA4QzguMzA0NTkgMTAuMjEgMTAuMDg1OCAxMiAxMi4yODUgMTJDMTQuNDg0MSAxMiAxNi4yNjUzIDEwLjIxIDE2LjI2NTMgOEMxNi4yNjUzIDUuNzkgMTQuNDg0MSA0IDEyLjI4NSA0Wk0xNC4yNzUxIDhDMTQuMjc1MSA2LjkgMTMuMzc5NiA2IDEyLjI4NSA2QzExLjE5MDQgNiAxMC4yOTQ4IDYuOSAxMC4yOTQ4IDhDMTAuMjk0OCA5LjEgMTEuMTkwNCAxMCAxMi4yODUgMTBDMTMuMzc5NiAxMCAxNC4yNzUxIDkuMSAxNC4yNzUxIDhaTTE4LjI1NTUgMThDMTguMDU2NSAxNy4yOSAxNC45NzE3IDE2IDEyLjI4NSAxNkM5LjYwODE2IDE2IDYuNTQzMjcgMTcuMjggNi4zMTQ0IDE4SDE4LjI1NTVaTTQuMzI0MjIgMThDNC4zMjQyMiAxNS4zNCA5LjYyODA2IDE0IDEyLjI4NSAxNEMxNC45NDE4IDE0IDIwLjI0NTcgMTUuMzQgMjAuMjQ1NyAxOFYyMEg0LjMyNDIyVjE4WiIgZmlsbD0id2hpdGUiLz4KPC9tYXNrPgo8ZyBtYXNrPSJ1cmwoI21hc2swKSI+CjxyZWN0IHg9IjAuMzQzNzUiIHdpZHRoPSIyMy44ODIyIiBoZWlnaHQ9IjI0IiBmaWxsPSIjYTJhYWIyIi8+CjwvZz4KPC9zdmc+Cg=="); }

.jp-connection-status-card--line {
  width: 67px;
  height: 0;
  border-top: 2px solid #000000; }
  .jp-connection-status-card--line.jp-connection-status-card--site-only {
    border-top-style: dashed; }

.jp-connection-status-card--list {
  list-style-type: none; }
  .jp-connection-status-card--list li {
    padding-left: 25px;
    color: #000;
    margin-bottom: 9px; }
  .jp-connection-status-card--list-item-success {
    background: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjQiIGhlaWdodD0iMjQiIHZpZXdCb3g9IjAgMCAyNCAyNCIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPHBhdGggZD0iTTE4LjkzNDggNi4wMDAwM0wxMC4wMzQyIDE3Ljk3MDNMNC44NzMxIDE0LjEzMjgiIHN0cm9rZT0iIzFFMUUxRSIgc3Ryb2tlLXdpZHRoPSIxLjUiLz4KPC9zdmc+Cg==") no-repeat 0 0; }
  .jp-connection-status-card--list-item-error {
    color: #D63639 !important;
    color: var(--jp-red) !important;
    background: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjQiIGhlaWdodD0iMjQiIHZpZXdCb3g9IjAgMCAyNCAyNCIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPHBhdGggZD0iTTEyIDIwQzE2LjQxODMgMjAgMjAgMTYuNDE4MyAyMCAxMkMyMCA3LjU4MTcyIDE2LjQxODMgNCAxMiA0QzcuNTgxNzIgNCA0IDcuNTgxNzIgNCAxMkM0IDE2LjQxODMgNy41ODE3MiAyMCAxMiAyMFoiIHN0cm9rZT0iI0Q2MzYzOSIgc3Ryb2tlLXdpZHRoPSIxLjUiLz4KPHBhdGggZD0iTTEzIDdIMTFWMTNIMTNWN1oiIGZpbGw9IiNENjM2MzkiLz4KPHBhdGggZD0iTTEzIDE1SDExVjE3SDEzVjE1WiIgZmlsbD0iI0Q2MzYzOSIvPgo8L3N2Zz4K") no-repeat 0 0; }

#jetpack-connection-ui-container .jetpack-cui__header h1 {
  text-align: left;
  font-size: 4.6em;
  line-height: 1.2em; }

#jetpack-connection-ui-container {
  margin: 40px; }
  #jetpack-connection-ui-container p {
    font-size: 1.23em;
    line-height: 1.5em; }


/*# sourceMappingURL=index.css.map*/