<?php

// This file `jetpack_autoload_classmap.php` was auto generated by automattic/jetpack-autoloader.

$vendorDir = dirname(__DIR__);
$baseDir   = dirname($vendorDir);

return array(
	'Automattic\\Jetpack\\Autoloader\\AutoloadGenerator' => array(
		'version' => '2.10.3.0',
		'path'    => $vendorDir . '/automattic/jetpack-autoloader/src/AutoloadGenerator.php'
	),
	'Automattic\\Jetpack\\Autoloader\\AutoloadProcessor' => array(
		'version' => '2.10.3.0',
		'path'    => $vendorDir . '/automattic/jetpack-autoloader/src/AutoloadProcessor.php'
	),
	'Automattic\\Jetpack\\Autoloader\\AutoloadFileWriter' => array(
		'version' => '2.10.3.0',
		'path'    => $vendorDir . '/automattic/jetpack-autoloader/src/AutoloadFileWriter.php'
	),
	'Automattic\\Jetpack\\Autoloader\\CustomAutoloaderPlugin' => array(
		'version' => '2.10.3.0',
		'path'    => $vendorDir . '/automattic/jetpack-autoloader/src/CustomAutoloaderPlugin.php'
	),
	'Automattic\\Jetpack\\Autoloader\\ManifestGenerator' => array(
		'version' => '2.10.3.0',
		'path'    => $vendorDir . '/automattic/jetpack-autoloader/src/ManifestGenerator.php'
	),
	'Twitter\\Text\\HitHighlighter' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/HitHighlighter.php'
	),
	'Twitter\\Text\\Extractor' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/Extractor.php'
	),
	'Twitter\\Text\\Regex' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/Regex.php'
	),
	'Twitter\\Text\\EmojiRegex' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/EmojiRegex.php'
	),
	'Twitter\\Text\\Configuration' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/Configuration.php'
	),
	'Twitter\\Text\\TldLists' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/TldLists.php'
	),
	'Twitter\\Text\\Parser' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/Parser.php'
	),
	'Twitter\\Text\\Validator' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/Validator.php'
	),
	'Twitter\\Text\\StringUtils' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/StringUtils.php'
	),
	'Twitter\\Text\\Autolink' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/Autolink.php'
	),
	'Twitter\\Text\\ParseResults' => array(
		'version' => '3.1.2.0',
		'path'    => $vendorDir . '/nojimage/twitter-text-php/lib/Twitter/Text/ParseResults.php'
	),
	'Automattic\\Jetpack\\Plugin\\Tracking' => array(
		'version' => 'dev-master',
		'path'    => $baseDir . '/src/class-tracking.php'
	),
	'Automattic\\Jetpack\\Licensing' => array(
		'version' => '1.4.4.0',
		'path'    => $vendorDir . '/automattic/jetpack-licensing/src/class-licensing.php'
	),
	'Automattic\\Jetpack\\Jetpack_Lazy_Images' => array(
		'version' => '1.5.0.0',
		'path'    => $vendorDir . '/automattic/jetpack-lazy-images/src/lazy-images.php'
	),
	'Automattic\\Jetpack\\JITMS\\JITM' => array(
		'version' => '1.16.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-jitm/src/class-jitm.php'
	),
	'Automattic\\Jetpack\\JITMS\\Rest_Api_Endpoints' => array(
		'version' => '1.16.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-jitm/src/class-rest-api-endpoints.php'
	),
	'Automattic\\Jetpack\\JITMS\\Post_Connection_JITM' => array(
		'version' => '1.16.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-jitm/src/class-post-connection-jitm.php'
	),
	'Automattic\\Jetpack\\JITMS\\Pre_Connection_JITM' => array(
		'version' => '1.16.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-jitm/src/class-pre-connection-jitm.php'
	),
	'Automattic\\Jetpack\\ConnectionUI\\Initial_State' => array(
		'version' => '1.3.0.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection-ui/src/class-initial-state.php'
	),
	'Automattic\\Jetpack\\ConnectionUI\\Admin' => array(
		'version' => '1.3.0.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection-ui/src/class-admin.php'
	),
	'Automattic\\Jetpack\\Config' => array(
		'version' => '1.4.6.0',
		'path'    => $vendorDir . '/automattic/jetpack-config/src/class-config.php'
	),
	'Automattic\\Jetpack\\Abtest' => array(
		'version' => '1.9.9.0',
		'path'    => $vendorDir . '/automattic/jetpack-abtest/src/class-abtest.php'
	),
	'Jetpack_Sync_Actions' => array(
		'version' => '1.6.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-compat/legacy/class-jetpack-sync-actions.php'
	),
	'Jetpack_Sync_Settings' => array(
		'version' => '1.6.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-compat/legacy/class-jetpack-sync-settings.php'
	),
	'JetpackTracking' => array(
		'version' => '1.6.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-compat/legacy/class-jetpacktracking.php'
	),
	'Jetpack_Client' => array(
		'version' => '1.6.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-compat/legacy/class-jetpack-client.php'
	),
	'Jetpack_Sync_Modules' => array(
		'version' => '1.6.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-compat/legacy/class-jetpack-sync-modules.php'
	),
	'Automattic\\Jetpack\\Blocks' => array(
		'version' => '1.4.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-blocks/src/class-blocks.php'
	),
	'Automattic\\Jetpack\\Backup\\REST_Controller' => array(
		'version' => '1.1.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-backup/src/class-rest-controller.php'
	),
	'Automattic\\Jetpack\\Backup\\Helper_Script_Manager' => array(
		'version' => '1.1.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-backup/src/class-helper-script-manager.php'
	),
	'Automattic\\Jetpack\\Backup\\Package_Version' => array(
		'version' => '1.1.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-backup/src/class-package-version.php'
	),
	'Automattic\\Jetpack\\Partner' => array(
		'version' => '1.5.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-partner/src/class-partner.php'
	),
	'Automattic\\Jetpack\\Sync\\Utils' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-utils.php'
	),
	'Automattic\\Jetpack\\Sync\\Users' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-users.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Users' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-users.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Full_Sync' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-full-sync.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Menus' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-menus.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Terms' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-terms.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Term_Relationships' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-term-relationships.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Comments' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-comments.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Full_Sync_Immediately' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-full-sync-immediately.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Options' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-options.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Constants' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-constants.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Network_Options' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-network-options.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Themes' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-themes.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Stats' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-stats.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Protect' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-protect.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Import' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-import.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\WooCommerce' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-woocommerce.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Meta' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-meta.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Attachments' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-attachments.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Updates' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-updates.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Callables' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-callables.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Plugins' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-plugins.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Module' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-module.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\Posts' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-posts.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules\\WP_Super_Cache' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/modules/class-wp-super-cache.php'
	),
	'Automattic\\Jetpack\\Sync\\Server' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-server.php'
	),
	'Automattic\\Jetpack\\Sync\\Actions' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-actions.php'
	),
	'Automattic\\Jetpack\\Sync\\Main' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-main.php'
	),
	'Automattic\\Jetpack\\Sync\\Simple_Codec' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-simple-codec.php'
	),
	'Automattic\\Jetpack\\Sync\\Queue' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-queue.php'
	),
	'Automattic\\Jetpack\\Sync\\Functions' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-functions.php'
	),
	'Automattic\\Jetpack\\Sync\\Replicastore_Interface' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/interface-replicastore.php'
	),
	'Automattic\\Jetpack\\Sync\\Lock' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-lock.php'
	),
	'Automattic\\Jetpack\\Sync\\Replicastore' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-replicastore.php'
	),
	'Automattic\\Jetpack\\Sync\\Settings' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-settings.php'
	),
	'Automattic\\Jetpack\\Sync\\Listener' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-listener.php'
	),
	'Automattic\\Jetpack\\Sync\\Sender' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-sender.php'
	),
	'Automattic\\Jetpack\\Sync\\Codec_Interface' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/interface-codec.php'
	),
	'Automattic\\Jetpack\\Sync\\JSON_Deflate_Array_Codec' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-json-deflate-array-codec.php'
	),
	'Automattic\\Jetpack\\Sync\\Modules' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-modules.php'
	),
	'Automattic\\Jetpack\\Sync\\REST_Endpoints' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-rest-endpoints.php'
	),
	'Automattic\\Jetpack\\Sync\\Replicastore\\Table_Checksum' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/replicastore/class-table-checksum.php'
	),
	'Automattic\\Jetpack\\Sync\\Health' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-health.php'
	),
	'Automattic\\Jetpack\\Sync\\Package_Version' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-package-version.php'
	),
	'Automattic\\Jetpack\\Sync\\REST_Sender' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-rest-sender.php'
	),
	'Automattic\\Jetpack\\Sync\\Defaults' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-defaults.php'
	),
	'Automattic\\Jetpack\\Sync\\Queue_Buffer' => array(
		'version' => '1.24.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-sync/src/class-queue-buffer.php'
	),
	'Automattic\\Jetpack\\Error' => array(
		'version' => '1.3.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-error/src/class-error.php'
	),
	'Automattic\\Jetpack\\Device_Detection' => array(
		'version' => '1.4.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-device-detection/src/class-device-detection.php'
	),
	'Automattic\\Jetpack\\Device_Detection\\User_Agent_Info' => array(
		'version' => '1.4.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-device-detection/src/class-user-agent-info.php'
	),
	'Automattic\\Jetpack\\IdentityCrisis\\REST_Endpoints' => array(
		'version' => '0.2.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-identity-crisis/src/class-rest-endpoints.php'
	),
	'Automattic\\Jetpack\\Identity_Crisis' => array(
		'version' => '0.2.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-identity-crisis/src/class-identity-crisis.php'
	),
	'Automattic\\Jetpack\\Password_Checker' => array(
		'version' => '0.1.2.0',
		'path'    => $vendorDir . '/automattic/jetpack-password-checker/src/class-password-checker.php'
	),
	'Automattic\\Jetpack\\Assets\\Logo' => array(
		'version' => '1.5.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-logo/src/class-logo.php'
	),
	'Jetpack_Signature' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/legacy/class-jetpack-signature.php'
	),
	'Jetpack_IXR_ClientMulticall' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/legacy/class-jetpack-ixr-clientmulticall.php'
	),
	'Jetpack_XMLRPC_Server' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/legacy/class-jetpack-xmlrpc-server.php'
	),
	'Jetpack_IXR_Client' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/legacy/class-jetpack-ixr-client.php'
	),
	'Automattic\\Jetpack\\Connection\\Utils' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-utils.php'
	),
	'Automattic\\Jetpack\\Connection\\Client' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-client.php'
	),
	'Automattic\\Jetpack\\Connection\\Nonce_Handler' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-nonce-handler.php'
	),
	'Automattic\\Jetpack\\Connection\\Plugin' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-plugin.php'
	),
	'Automattic\\Jetpack\\Connection\\Tokens' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-tokens.php'
	),
	'Automattic\\Jetpack\\Connection\\Manager' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-manager.php'
	),
	'Automattic\\Jetpack\\Connection\\Urls' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-urls.php'
	),
	'Automattic\\Jetpack\\Connection\\REST_Connector' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-rest-connector.php'
	),
	'Automattic\\Jetpack\\Connection\\Manager_Interface' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/interface-manager.php'
	),
	'Automattic\\Jetpack\\Connection\\Webhooks' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-webhooks.php'
	),
	'Automattic\\Jetpack\\Connection\\Rest_Authentication' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-rest-authentication.php'
	),
	'Automattic\\Jetpack\\Connection\\XMLRPC_Async_Call' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-xmlrpc-async-call.php'
	),
	'Automattic\\Jetpack\\Connection\\Secrets' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-secrets.php'
	),
	'Automattic\\Jetpack\\Connection\\Package_Version' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-package-version.php'
	),
	'Automattic\\Jetpack\\Connection\\Error_Handler' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-error-handler.php'
	),
	'Automattic\\Jetpack\\Connection\\Plugin_Storage' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-plugin-storage.php'
	),
	'Automattic\\Jetpack\\Connection\\XMLRPC_Connector' => array(
		'version' => '1.30.1.0',
		'path'    => $vendorDir . '/automattic/jetpack-connection/src/class-xmlrpc-connector.php'
	),
	'Automattic\\Jetpack\\Redirect' => array(
		'version' => '1.7.0.0',
		'path'    => $vendorDir . '/automattic/jetpack-redirect/src/class-redirect.php'
	),
	'Automattic\\Jetpack\\Heartbeat' => array(
		'version' => '1.3.8.0',
		'path'    => $vendorDir . '/automattic/jetpack-heartbeat/src/class-heartbeat.php'
	),
	'Automattic\\Jetpack\\Roles' => array(
		'version' => '1.4.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-roles/src/class-roles.php'
	),
	'Jetpack_Tracks_Client' => array(
		'version' => '1.13.7.0',
		'path'    => $vendorDir . '/automattic/jetpack-tracking/legacy/class-jetpack-tracks-client.php'
	),
	'Jetpack_Tracks_Event' => array(
		'version' => '1.13.7.0',
		'path'    => $vendorDir . '/automattic/jetpack-tracking/legacy/class-jetpack-tracks-event.php'
	),
	'Automattic\\Jetpack\\Tracking' => array(
		'version' => '1.13.7.0',
		'path'    => $vendorDir . '/automattic/jetpack-tracking/src/class-tracking.php'
	),
	'Automattic\\Jetpack\\Assets' => array(
		'version' => '1.11.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-assets/src/class-assets.php'
	),
	'Automattic\\Jetpack\\A8c_Mc_Stats' => array(
		'version' => '1.4.4.0',
		'path'    => $vendorDir . '/automattic/jetpack-a8c-mc-stats/src/class-a8c-mc-stats.php'
	),
	'Automattic\\Jetpack\\Terms_Of_Service' => array(
		'version' => '1.9.8.0',
		'path'    => $vendorDir . '/automattic/jetpack-terms-of-service/src/class-terms-of-service.php'
	),
	'Automattic\\Jetpack\\Status' => array(
		'version' => '1.8.0.0',
		'path'    => $vendorDir . '/automattic/jetpack-status/src/class-status.php'
	),
	'Jetpack_Options' => array(
		'version' => '1.13.0.0',
		'path'    => $vendorDir . '/automattic/jetpack-options/legacy/class-jetpack-options.php'
	),
	'Automattic\\Jetpack\\Constants' => array(
		'version' => '1.6.5.0',
		'path'    => $vendorDir . '/automattic/jetpack-constants/src/class-constants.php'
	),
);
