.eventbrite__direct-link:not(:only-child){display:none}.wp-block-jetpack-eventbrite--embed{height:auto!important}.wp-block-jetpack-eventbrite--embed iframe{height:425px}.wp-block-jetpack-eventbrite--embed.aligncenter{text-align:center}.eventbrite__lightbox{background:rgba(57,54,79,.8)}.eventbrite__lighbox-inside{width:100%;height:100%;position:absolute;display:flex;align-items:center;justify-content:center}@media (max-width:660px){.eventbrite__lighbox-iframe-wrapper{position:absolute;top:0;right:0;left:0;bottom:0}}@media (min-width:661px){.eventbrite__lighbox-iframe-wrapper{width:95%;height:95%;max-width:1080px;max-height:720px;margin:auto;position:relative}}.eventbrite__lighbox-iframe{margin:0}.eventbrite__lighbox-close{position:absolute;top:0;left:0;width:40px;height:40px}