<?php

namespace Dotenv\Exception;

use InvalidArgumentException;

/**
 * This is the invalid file exception class.
 */
class InvalidFileException extends InvalidArgumentException implements ExceptionInterface
{
    //
}
