<?php

namespace Dotenv\Exception;

use InvalidArgumentException;

/**
 * This is the invalid path exception class.
 */
class InvalidPathException extends InvalidArgumentException implements ExceptionInterface
{
    //
}
