.wp-block-jetpack-donations .donations__container{border:1px solid #ccc}.wp-block-jetpack-donations .donations__nav{display:flex;border-bottom:1px solid #ccc}.wp-block-jetpack-donations .donations__nav-item{font-weight:700;display:inline-block;flex:1;text-align:center;font-size:16px;padding:12px;border-left:1px solid #ccc;background:#fff;color:#1e1e1e;cursor:pointer}@media (min-width:600px){.wp-block-jetpack-donations .donations__nav-item{padding:16px 24px}}.wp-block-jetpack-donations .donations__nav-item:first-child{border-left:none}.wp-block-jetpack-donations .donations__nav-item.is-active{background:#007cba;color:#fff;cursor:default}.wp-block-jetpack-donations .donations__content{padding:16px}@media (min-width:600px){.wp-block-jetpack-donations .donations__content{padding:32px}}.wp-block-jetpack-donations .donations__content h4,.wp-block-jetpack-donations .donations__content p{margin:0 0 16px}@media (min-width:600px){.wp-block-jetpack-donations .donations__content h4,.wp-block-jetpack-donations .donations__content p{margin:0 0 24px}}.wp-block-jetpack-donations .donations__amounts{margin-bottom:16px;display:flex;flex-wrap:wrap}@media (min-width:600px){.wp-block-jetpack-donations .donations__amounts{margin:0 0 24px}}.wp-block-jetpack-donations .donations__amount{display:inline-block;padding:16px 24px;background-color:#fff;color:#1e1e1e;border:1px solid #ccc;margin-right:8px;margin-bottom:8px;font-weight:600;font-size:16px;white-space:nowrap}.wp-block-jetpack-donations .donations__amount.has-error{box-shadow:0 0 0 1px #fff,0 0 0 3px #d94f4f;outline:2px solid transparent;outline-offset:-2px}.wp-block-jetpack-donations .donations__custom-amount .donations__amount-value{margin-left:4px;min-width:60px}.wp-block-jetpack-donations .donations__separator{margin-bottom:16px;margin-top:16px}@media (min-width:600px){.wp-block-jetpack-donations .donations__separator{margin-bottom:32px;margin-top:32px}}.wp-block-jetpack-donations .donations__donate-button,.wp-block-jetpack-donations .donations__donate-button-wrapper{margin:0}.jetpack-memberships-modal #TB_title{display:none}#TB_window.jetpack-memberships-modal{background-color:transparent;background-image:url(https://s0.wp.com/i/loading/dark-200.gif);background-size:50px;background-repeat:no-repeat;background-position:center 150px;box-shadow:none;-webkit-box-shadow:none;-moz-box-shadow:none;border:none;height:100%}#TB_window.jetpack-memberships-modal,.jetpack-memberships-modal #TB_iframeContent{margin:0!important;bottom:0;left:0;position:absolute;right:0;top:0;width:100%!important}.jetpack-memberships-modal #TB_iframeContent{height:100%!important}BODY.modal-open{overflow:hidden}@keyframes spinner{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}.wp-block-jetpack-donations .donations__container:not(.loaded){width:100%;height:200px;position:relative}.wp-block-jetpack-donations .donations__container:not(.loaded) *{display:none}.wp-block-jetpack-donations .donations__container:not(.loaded):before{content:"";background-color:#949494;width:18px;height:18px;opacity:.7;border-radius:100%;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.wp-block-jetpack-donations .donations__container:not(.loaded):after{content:"";background-color:#fff;width:4px;height:4px;border-radius:100%;position:absolute;top:50%;left:50%;margin-left:-6px;margin-top:-6px;transform-origin:6px 6px;animation:spinner 1s linear infinite}.wp-block-jetpack-donations .donations__tab.is-annual .donations__monthly-item,.wp-block-jetpack-donations .donations__tab.is-annual .donations__one-time-item,.wp-block-jetpack-donations .donations__tab.is-monthly .donations__annual-item,.wp-block-jetpack-donations .donations__tab.is-monthly .donations__one-time-item,.wp-block-jetpack-donations .donations__tab.is-one-time .donations__annual-item,.wp-block-jetpack-donations .donations__tab.is-one-time .donations__monthly-item{display:none}.wp-block-jetpack-donations .donations__amount{cursor:pointer}.wp-block-jetpack-donations .donations__amount.is-selected{box-shadow:0 0 0 1px #fff,0 0 0 3px #007cba;outline:2px solid transparent;outline-offset:-2px}.wp-block-jetpack-donations .donations__custom-amount{cursor:text}.wp-block-jetpack-donations .donations__custom-amount .donations__amount-value{white-space:pre-wrap;display:inline-block;text-align:left}.wp-block-jetpack-donations .donations__custom-amount .donations__amount-value:empty:after{content:attr(data-empty-text);color:#ccc}.wp-block-jetpack-donations .donations__custom-amount .donations__amount-value:focus{outline:none}.wp-block-jetpack-donations .donations__donate-button.is-disabled{pointer-events:none;opacity:.2}