<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'Bluehost\\AccessToken' => $baseDir . '/inc/AccessToken.php',
    'Bluehost\\AdminBar' => $baseDir . '/inc/AdminBar.php',
    'Bluehost\\BuildAssets' => $baseDir . '/inc/BuildAssets.php',
    'Bluehost\\LoginRedirect' => $baseDir . '/inc/LoginRedirect.php',
    'Bluehost\\Notifications\\AdminNotices' => $baseDir . '/inc/Notifications/AdminNotices.php',
    'Bluehost\\Notifications\\Notification' => $baseDir . '/inc/Notifications/Notification.php',
    'Bluehost\\Notifications\\NotificationsApi' => $baseDir . '/inc/Notifications/NotificationsApi.php',
    'Bluehost\\Notifications\\NotificationsRepository' => $baseDir . '/inc/Notifications/NotificationsRepository.php',
    'Bluehost\\ResponseUtilities' => $baseDir . '/inc/ResponseUtilities.php',
    'Bluehost\\RestApi\\AdminErrorController' => $baseDir . '/inc/RestApi/AdminErrorController.php',
    'Bluehost\\RestApi\\BluehostBlogController' => $baseDir . '/inc/RestApi/BluehostBlogController.php',
    'Bluehost\\RestApi\\CachingController' => $baseDir . '/inc/RestApi/CachingController.php',
    'Bluehost\\RestApi\\MojoItemController' => $baseDir . '/inc/RestApi/MojoItemController.php',
    'Bluehost\\RestApi\\MojoItemsController' => $baseDir . '/inc/RestApi/MojoItemsController.php',
    'Bluehost\\RestApi\\MojoPluginsController' => $baseDir . '/inc/RestApi/MojoPluginsController.php',
    'Bluehost\\RestApi\\MojoServicesController' => $baseDir . '/inc/RestApi/MojoServicesController.php',
    'Bluehost\\RestApi\\MojoThemesController' => $baseDir . '/inc/RestApi/MojoThemesController.php',
    'Bluehost\\RestApi\\SettingsController' => $baseDir . '/inc/RestApi/SettingsController.php',
    'Bluehost\\RestApi\\StagingController' => $baseDir . '/inc/RestApi/StagingController.php',
    'Bluehost\\SiteMeta' => $baseDir . '/inc/SiteMeta.php',
    'Bluehost\\Staging' => $baseDir . '/inc/Staging.php',
    'Bluehost\\UpgradeHandler' => $baseDir . '/inc/UpgradeHandler.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'Doctrine\\Common\\Inflector\\Inflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Common/Inflector/Inflector.php',
    'Doctrine\\Inflector\\CachedWordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/CachedWordInflector.php',
    'Doctrine\\Inflector\\GenericLanguageInflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/GenericLanguageInflectorFactory.php',
    'Doctrine\\Inflector\\Inflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Inflector.php',
    'Doctrine\\Inflector\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/InflectorFactory.php',
    'Doctrine\\Inflector\\Language' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Language.php',
    'Doctrine\\Inflector\\LanguageInflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/LanguageInflectorFactory.php',
    'Doctrine\\Inflector\\NoopWordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/NoopWordInflector.php',
    'Doctrine\\Inflector\\Rules\\English\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\English\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\English\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Rules.php',
    'Doctrine\\Inflector\\Rules\\English\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/English/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\French\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\French\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\French\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Rules.php',
    'Doctrine\\Inflector\\Rules\\French\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/French/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Rules.php',
    'Doctrine\\Inflector\\Rules\\NorwegianBokmal\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/NorwegianBokmal/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Pattern' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Pattern.php',
    'Doctrine\\Inflector\\Rules\\Patterns' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Patterns.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Rules.php',
    'Doctrine\\Inflector\\Rules\\Portuguese\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Portuguese/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Ruleset' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Ruleset.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Rules.php',
    'Doctrine\\Inflector\\Rules\\Spanish\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Spanish/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Substitution' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Substitution.php',
    'Doctrine\\Inflector\\Rules\\Substitutions' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Substitutions.php',
    'Doctrine\\Inflector\\Rules\\Transformation' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Transformation.php',
    'Doctrine\\Inflector\\Rules\\Transformations' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Transformations.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Inflectible' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Inflectible.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\InflectorFactory' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/InflectorFactory.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Rules' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Rules.php',
    'Doctrine\\Inflector\\Rules\\Turkish\\Uninflected' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Turkish/Uninflected.php',
    'Doctrine\\Inflector\\Rules\\Word' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/Rules/Word.php',
    'Doctrine\\Inflector\\RulesetInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/RulesetInflector.php',
    'Doctrine\\Inflector\\WordInflector' => $vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector/WordInflector.php',
    'EIG_Module_Gutenframe' => $vendorDir . '/bluehost/endurance-wp-module-gutenframe/src/class-eig-module-gutenframe.php',
    'Endurance\\WP\\Module\\Data\\API\\Events' => $vendorDir . '/endurance/wp-module-data/src/API/Events.php',
    'Endurance\\WP\\Module\\Data\\API\\Verify' => $vendorDir . '/endurance/wp-module-data/src/API/Verify.php',
    'Endurance\\WP\\Module\\Data\\Data' => $vendorDir . '/endurance/wp-module-data/src/Data.php',
    'Endurance\\WP\\Module\\Data\\Encryption' => $vendorDir . '/endurance/wp-module-data/src/Encryption.php',
    'Endurance\\WP\\Module\\Data\\Event' => $vendorDir . '/endurance/wp-module-data/src/Event.php',
    'Endurance\\WP\\Module\\Data\\EventManager' => $vendorDir . '/endurance/wp-module-data/src/EventManager.php',
    'Endurance\\WP\\Module\\Data\\HubConnection' => $vendorDir . '/endurance/wp-module-data/src/HubConnection.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\Admin' => $vendorDir . '/endurance/wp-module-data/src/Listeners/Admin.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\BHPlugin' => $vendorDir . '/endurance/wp-module-data/src/Listeners/BHPlugin.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\Content' => $vendorDir . '/endurance/wp-module-data/src/Listeners/Content.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\Cron' => $vendorDir . '/endurance/wp-module-data/src/Listeners/Cron.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\Jetpack' => $vendorDir . '/endurance/wp-module-data/src/Listeners/Jetpack.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\Listener' => $vendorDir . '/endurance/wp-module-data/src/Listeners/Listener.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\Plugin' => $vendorDir . '/endurance/wp-module-data/src/Listeners/Plugin.php',
    'Endurance\\WP\\Module\\Data\\Listeners\\Theme' => $vendorDir . '/endurance/wp-module-data/src/Listeners/Theme.php',
    'Endurance\\WP\\Module\\Data\\Logger' => $vendorDir . '/endurance/wp-module-data/src/Logger.php',
    'Endurance\\WP\\Module\\Data\\SubscriberInterface' => $vendorDir . '/endurance/wp-module-data/src/SubscriberInterface.php',
    'Endurance\\WP\\Module\\Data\\Transient' => $vendorDir . '/endurance/wp-module-data/src/Transient.php',
    'Endurance_Collection' => $vendorDir . '/bluehost/endurance-wp-module-loader/includes/Collection.php',
    'Endurance_ModuleManager' => $vendorDir . '/bluehost/endurance-wp-module-loader/includes/ModuleManager.php',
    'Endurance_ModuleRegistry' => $vendorDir . '/bluehost/endurance-wp-module-loader/includes/ModuleRegistry.php',
    'Endurance_Options' => $vendorDir . '/bluehost/endurance-wp-module-loader/includes/Options.php',
    'Endurance_WP_Plugin_Updater\\Plugin' => $vendorDir . '/bluehost/endurance-wp-plugin-updater/Plugin.php',
    'Endurance_WP_Plugin_Updater\\Updater' => $vendorDir . '/bluehost/endurance-wp-plugin-updater/Updater.php',
    'Newfold\\Plugin\\DefaultContent\\Pages' => $baseDir . '/inc/DefaultContent/Pages.php',
    'Newfold\\Plugin\\DefaultContent\\PagesRestController' => $baseDir . '/inc/DefaultContent/PagesRestController.php',
    'Newfold\\Plugin\\RestApi\\BaseHiiveController' => $baseDir . '/inc/RestApi/BaseHiiveController.php',
    'Newfold\\Plugin\\Tours\\BlockEditor' => $baseDir . '/inc/Tours/BlockEditor.php',
    'Newfold\\Plugin\\Tours\\BlockEditorRestController' => $baseDir . '/inc/Tours/BlockEditorRestController.php',
    'Newfold\\Plugin\\Tours\\Customizer' => $baseDir . '/inc/Tours/Customizer.php',
    'Newfold\\Plugin\\Tours\\Shared' => $baseDir . '/inc/Tours/Shared.php',
    'Pimple\\Container' => $vendorDir . '/pimple/pimple/src/Pimple/Container.php',
    'Pimple\\Exception\\ExpectedInvokableException' => $vendorDir . '/pimple/pimple/src/Pimple/Exception/ExpectedInvokableException.php',
    'Pimple\\Exception\\FrozenServiceException' => $vendorDir . '/pimple/pimple/src/Pimple/Exception/FrozenServiceException.php',
    'Pimple\\Exception\\InvalidServiceIdentifierException' => $vendorDir . '/pimple/pimple/src/Pimple/Exception/InvalidServiceIdentifierException.php',
    'Pimple\\Exception\\UnknownIdentifierException' => $vendorDir . '/pimple/pimple/src/Pimple/Exception/UnknownIdentifierException.php',
    'Pimple\\Psr11\\Container' => $vendorDir . '/pimple/pimple/src/Pimple/Psr11/Container.php',
    'Pimple\\Psr11\\ServiceLocator' => $vendorDir . '/pimple/pimple/src/Pimple/Psr11/ServiceLocator.php',
    'Pimple\\ServiceIterator' => $vendorDir . '/pimple/pimple/src/Pimple/ServiceIterator.php',
    'Pimple\\ServiceProviderInterface' => $vendorDir . '/pimple/pimple/src/Pimple/ServiceProviderInterface.php',
    'Pimple\\Tests\\Fixtures\\Invokable' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/Fixtures/Invokable.php',
    'Pimple\\Tests\\Fixtures\\NonInvokable' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/Fixtures/NonInvokable.php',
    'Pimple\\Tests\\Fixtures\\PimpleServiceProvider' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/Fixtures/PimpleServiceProvider.php',
    'Pimple\\Tests\\Fixtures\\Service' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/Fixtures/Service.php',
    'Pimple\\Tests\\PimpleServiceProviderInterfaceTest' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/PimpleServiceProviderInterfaceTest.php',
    'Pimple\\Tests\\PimpleTest' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/PimpleTest.php',
    'Pimple\\Tests\\Psr11\\ContainerTest' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/Psr11/ContainerTest.php',
    'Pimple\\Tests\\Psr11\\ServiceLocatorTest' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/Psr11/ServiceLocatorTest.php',
    'Pimple\\Tests\\ServiceIteratorTest' => $vendorDir . '/pimple/pimple/src/Pimple/Tests/ServiceIteratorTest.php',
    'Psr\\Container\\ContainerExceptionInterface' => $vendorDir . '/psr/container/src/ContainerExceptionInterface.php',
    'Psr\\Container\\ContainerInterface' => $vendorDir . '/psr/container/src/ContainerInterface.php',
    'Psr\\Container\\NotFoundExceptionInterface' => $vendorDir . '/psr/container/src/NotFoundExceptionInterface.php',
    'WP_Forge\\Helpers\\Arr' => $vendorDir . '/wp-forge/helpers/includes/Arr.php',
    'WP_Forge\\Helpers\\Pluralizer' => $vendorDir . '/wp-forge/helpers/includes/Pluralizer.php',
    'WP_Forge\\Helpers\\Str' => $vendorDir . '/wp-forge/helpers/includes/Str.php',
    'wpscholar\\Collection' => $vendorDir . '/wpscholar/collection/Collection.php',
    'wpscholar\\Url' => $vendorDir . '/wpscholar/url/Url.php',
);
