<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'Sabberworm\\CSS' => array($vendorDir . '/sabberworm/php-css-parser/lib'),
    'Raygun4php' => array($vendorDir . '/mindscape/raygun4php/src'),
);
