.page-settings__grid1{display:-ms-grid;display:grid;row-gap:1.5rem;-moz-column-gap:3rem;column-gap:3rem;padding-bottom:1.5rem}@media(min-width: 782px){.page-settings__grid1{-ms-grid-columns:(minmax(0, 1fr))[2];grid-template-columns:repeat(2, minmax(0, 1fr))}}.page-settings__block{padding:24px}
.settings-group{border:1px solid #d7dbe0;border-radius:3px;background-color:#fff}
.settings-section .settings-section__title{margin-top:0 !important}
.settings-control{font-size:16px;line-height:24px;padding:24px;border-bottom:1px solid #d7dadf;display:-ms-grid;display:grid;-ms-grid-columns:(minmax(0, 1fr))[4];grid-template-columns:repeat(4, minmax(0, 1fr))}.settings-control:last-child{border:none}.settings-control .label{-ms-grid-column-span:3;grid-column:span 3/span 3}
.component-template-common{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-common{padding:46px 0 24px}}@media(max-width: 600px){.component-template-common{padding-left:16px;padding-right:16px}}.page-fade-speed{-webkit-animation-duration:315ms;animation-duration:315ms}
.component-template-marketplace{padding:46px 24px 24px;max-width:1600px;margin:0 auto}@media screen and (min-width: 1814px){.component-template-marketplace{padding:46px 0 24px}}@media(max-width: 600px){.component-template-marketplace{padding-left:16px;padding-right:16px}}.bluehost-marketplace__header-primary{display:flex;justify-content:space-between;align-items:center;flex-wrap:wrap}.bluehost-marketplace__header-primary .marketplace-page-title{margin-top:0 !important;margin-bottom:0 !important;position:relative;top:-28px}@media screen and (min-width: 768px){.bluehost-marketplace__header-primary{max-height:64px}}.bluehost-marketplace__header-primary .pagination{margin-top:0}.bluehost-marketplace__header-secondary{display:flex;justify-content:space-between;align-items:center;margin-bottom:9px;flex-wrap:wrap}.bluehost-marketplace__header-secondary .search-box{margin-right:2em}.bluehost-marketplace__header-secondary .dropdown__label{font-weight:600}.bluehost-marketplace__pagination-container{min-height:96px}.bluehost-marketplace__footer{display:flex;justify-content:space-between;align-items:flex-start;margin-top:9px}.bluehost-marketplace__footer .pagination{margin-top:0}@media(max-width: 624px){.bluehost-marketplace h1{margin-top:0}.bluehost-marketplace .pagination{margin-top:1rem}.bluehost-marketplace .search-box{margin-bottom:1rem}}@media(max-width: 687px){.bluehost-marketplace .search-box{margin-bottom:1rem}}
.performance .caching{border:1px solid #d7dbe0;border-radius:3px;background-color:#fff}.performance .caching{position:relative;padding:24px}.performance .caching__title,.performance .caching__subtitle{margin:0 !important}.performance p{margin-top:8px;margin-bottom:24px;font-size:16px}.performance input[type=radio]{margin-top:1px}.performance .cache-level label{font-weight:600}.performance .cache-level .row{display:flex;margin-top:17px}.performance .cache-level .row:last-child{margin-bottom:32px}.performance .cache-level .row p{margin-bottom:0}.performance .onoffswitch{position:absolute;top:24px;right:24px}@media screen and (max-width: 782px){.performance input[type=radio]{height:1rem;width:1rem}.performance input[type=radio]:checked:before{height:.5rem;width:.5rem;margin:.1875rem}}
