//--------------------------------------------------------------
// Variables
//--------------------------------------------------------------

// Mobile break-point
$mobile-break : 450px;

// Fonts
$font-sans    : sans-serif;
$font-serif   : Georgia, Times, "Times New Roman", serif;
$font-mono    : "Courier 10 Pitch", Courier, monospace;
$font-size    : 14px;

// Colors
$dark-gray    : #222222;
$gray         : #757575;
$medium-gray  : #666;
$light-gray   : #e9e9e9;
$lightchecker : #eee;
$darkchecker  : #d0d0d0;
$blue         : #0063ce;
$light-yellow : #fffff8;
$white        : #ffffff;
$almostwhite  : #fafafa;
$red          : #f00;
$dark-red     : #a00;
