<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'wpscholar\\' => array($vendorDir . '/wpscholar/collection', $vendorDir . '/wpscholar/url'),
    'WP_Forge\\Helpers\\' => array($vendorDir . '/wp-forge/helpers/includes'),
    'Psr\\Container\\' => array($vendorDir . '/psr/container/src'),
    'Newfold\\Plugin\\' => array($baseDir . '/inc'),
    'Endurance_WP_Plugin_Updater\\' => array($vendorDir . '/bluehost/endurance-wp-plugin-updater'),
    'Endurance\\WP\\Module\\Data\\' => array($vendorDir . '/endurance/wp-module-data/src'),
    'Doctrine\\Inflector\\' => array($vendorDir . '/doctrine/inflector/lib/Doctrine/Inflector'),
    'Doctrine\\Common\\Inflector\\' => array($vendorDir . '/doctrine/inflector/lib/Doctrine/Common/Inflector'),
    'Bluehost\\' => array($baseDir . '/inc'),
);
