/**
	HTML markup structure of an ad:

	<div class="wpcnt">
		<div class="wpa [wpmrec|wpwidesky|wpleaderboard]">
			<a class="wpa-about" href="http://wordpress.com/about-these-ads/" rel="nofollow">
			About these ads
			</a>
			<div class="u">
				[ad unit here]
			</div>
		</div>
	</div>
*/

/* outer container */
.wpcnt {
	text-align: center;
	line-height: 2;
}

/* inner container */
.wpa {
	position: relative;
	overflow: hidden;			/* this hides "about these ads" when there's no adfill */
	display: inline-block;
	max-width: 100%;			/* important! this bit of CSS will *crop* any ad that's larger than the parent container! */
}

/* about these ads */
.wpa-about {
	position: absolute;
	top: 5px;
	left: 0;
	right: 0;
	display: block;
	margin-top: 0;
	color: #888;
	font: 10px/1 "Open Sans", Arial, sans-serif !important;
	text-align: left !important;
	text-decoration: none !important;
	opacity: 0.85;
	border-bottom: none !important;			/* some themes ad dotted underlines, that won't look nice */
	box-shadow: none !important;
}

/* ad unit wrapper */
.wpa .u>div {	/* @todo: deprecate wpdvert */
	display: block;
	margin-top: 5px;			/* this makes "about these ads" visible */
	margin-bottom: 1em;			/* every ad should have a little space below it */
}

div.wpa>div {
	margin-top: 20px;
}

.wpa .u .adsbygoogle {
	display: block;
	margin-top: 17px;			/* this makes "about these ads" visible */
	margin-bottom: 1em;			/* every ad should have a little space below it */
	background-color: transparent;
}
