<?php // @codingStandardsIgnoreStart ?>
<?php
/**
 * Template part for displaying a message that posts cannot be found
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Website Builder Theme
 */

?>
