<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'Wb4WpTheme\\Helpers\\Font_Helper' => $baseDir . '/src/helpers/class-font-helper.php',
    'Wb4WpTheme\\Helpers\\Object_Helper' => $baseDir . '/src/helpers/class-object-helper.php',
    'Wb4WpTheme\\Helpers\\Template_Helper' => $baseDir . '/src/helpers/class-template-helper.php',
    'Wb4WpTheme\\Managers\\Blog_Manager' => $baseDir . '/src/managers/class-blog-manager.php',
    'Wb4WpTheme\\Managers\\Color_Manager' => $baseDir . '/src/managers/class-color-manager.php',
    'Wb4WpTheme\\Managers\\Customize\\Controls\\Custom_Control' => $baseDir . '/src/managers/customize/controls/class-custom-control.php',
    'Wb4WpTheme\\Managers\\Customize\\Controls\\Toggle_Control' => $baseDir . '/src/managers/customize/controls/class-toggle-control.php',
    'Wb4WpTheme\\Managers\\Customize\\CustomizeControls' => $baseDir . '/src/managers/customize/CustomizeControls.php',
    'Wb4WpTheme\\Managers\\Customize\\CustomizeSettings' => $baseDir . '/src/managers/customize/CustomizeSettings.php',
    'Wb4WpTheme\\Managers\\Customize\\Customize_Controls' => $baseDir . '/src/managers/customize/class-customize-controls.php',
    'Wb4WpTheme\\Managers\\Customize\\Customize_Settings' => $baseDir . '/src/managers/customize/class-customize-settings.php',
    'Wb4WpTheme\\Managers\\Customize_Manager' => $baseDir . '/src/managers/class-customize-manager.php',
    'Wb4WpTheme\\Managers\\Template_Manager' => $baseDir . '/src/managers/class-template-manager.php',
    'Wb4WpTheme\\Managers\\Update_Manager' => $baseDir . '/src/managers/class-update-manager.php',
    'Wb4WpTheme\\Managers\\WordPress_Manager' => $baseDir . '/src/managers/class-wordpress-manager.php',
);
