.sharedaddy{width:100%;margin-right:auto;margin-left:auto;padding:4rem 15px}@media only screen and (min-width: 576px){.sharedaddy{max-width:540px}}@media only screen and (min-width: 768px){.sharedaddy{max-width:80%}}@media only screen and (min-width: 992px){.sharedaddy{max-width:75%}}@media only screen and (min-width: 1200px){.sharedaddy{max-width:70%}}@media only screen and (min-width: 1440px){.sharedaddy{max-width:65%}}@media only screen and (min-width: 1758px){.sharedaddy{max-width:1200px}}
